

'use strict';
{
  const globals = this;
  const django = globals.django || (globals.django = {});

  
  django.pluralidx = function(n) {
    const v = (n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;
    if (typeof v === 'boolean') {
      return v ? 1 : 0;
    } else {
      return v;
    }
  };
  

  /* gettext library */

  django.catalog = django.catalog || {};
  
  const newcatalog = {
    "%curr% of %total%": "%curr% z %total%",
    "(If left blank, owner will be admin)": "(Pokud je pr\u00e1zdn\u00e9, vlastn\u00edkem bude Admin)",
    "(at least {placeholder} characters)": "(nejm\u00e9n\u011b {placeholder} znak\u016f)",
    "(current notification)": "(aktu\u00e1ln\u00ed upozorn\u011bn\u00ed)",
    "(current version)": "(aktu\u00e1ln\u00ed verze)",
    "1 Year": "1 rok",
    "1 month ago": "1 m\u011bs\u00edc zp\u011bt",
    "1 week ago": "1 t\u00fdden zp\u011bt",
    "3 days ago": "3 dny zp\u011bt",
    "30 Days": "30 dn\u00ed",
    "7 Days": "7 dn\u00ed",
    "<a href=\"%url%\" target=\"_blank\">The image</a> could not be loaded.": "<a href=\"%url%\" target=\"_blank\">Obr\u00e1zek</a> nejde na\u010d\u00edst.",
    "A file is being uploaded. Are you sure you want to leave this page?": "Prob\u00edh\u00e1 nahr\u00e1v\u00e1n\u00ed souboru. Jste si jist\u00fd/\u00e1, \u017ee chcete opustit tuto str\u00e1nku?",
    "A file with the same name already exists in this folder.": "Soubor se stejn\u00fdm jm\u00e9nem ji\u017e existuje v t\u00e9to slo\u017ece.",
    "API token is copied to the clipboard.": "Token k API rozhran\u00ed zkop\u00edrov\u00e1n do schr\u00e1nky.",
    "About": "O aplikaci",
    "About Us": "O n\u00e1s",
    "Abuse Content": "Obsah zneu\u017eit\u00ed",
    "Abuse Reports": "Zpr\u00e1vy o zneu\u017e\u00edv\u00e1n\u00ed",
    "Abuse Type": "Typ zneu\u017eit\u00ed",
    "Accept": "P\u0159ijmout",
    "Accepted": "P\u0159ijato",
    "Accepter": "Potvrzuj\u00edc\u00ed",
    "Access Log": "Z\u00e1znam p\u0159\u00edstup\u016f",
    "Action": "Akce",
    "Actions": "Akce",
    "Activate user immediately after registration. If unchecked, a user need to be activated by administrator or via activation email": "Aktivovat nov\u00e9ho u\u017eivatele ihned po registraci. Pokud tuto polo\u017eku od\u0161krtnete, pak bude muset b\u00fdt u\u017eivatel aktivov\u00e1n pomoc\u00ed administr\u00e1tora nebo aktiva\u010dn\u00edho e-mailu.",
    "Activated": "Aktivov\u00e1no",
    "Activated Users": "Aktivovan\u00ed u\u017eivatel\u00e9",
    "Active": "Aktivn\u00ed",
    "Active Users": "Aktivn\u00ed u\u017eivatel\u00e9",
    "Activities": "Aktivity",
    "Add": "P\u0159idat",
    "Add Admin": "P\u0159idat spr\u00e1vce",
    "Add Admins": "P\u0159idat Administr\u00e1tory",
    "Add Institution": "P\u0159idat instituci",
    "Add Library": "P\u0159idat knihovnu",
    "Add Member": "P\u0159idat \u010dlena",
    "Add Organization": "P\u0159idat organizaci",
    "Add Terms and Conditions": "P\u0159idat pravidla a podm\u00ednky",
    "Add User": "P\u0159idat u\u017eivatele",
    "Add admin": "P\u0159idat Administr\u00e1tora",
    "Add auto expiration": "P\u0159idat automatickou expiraci",
    "Add group member": "P\u0159idat \u010dlena skupiny",
    "Add institution": "P\u0159idat instituci",
    "Add new notification": "P\u0159idat nov\u00e9 upozorn\u011bn\u00ed",
    "Add new reviewer": "P\u0159idat kontroln\u00edho u\u017eivatele",
    "Add password protection": "P\u0159idat ochranu heslem",
    "Add user": "P\u0159idat u\u017eivatele",
    "Added": "P\u0159id\u00e1no",
    "Added user {user}": "U\u017eivatel {user} byl p\u0159id\u00e1n",
    "Admin": "Admin",
    "Admin Login Logs": "Z\u00e1znamy p\u0159ihl\u00e1\u0161en\u00ed",
    "Admin Logs": "Administra\u010dn\u00ed z\u00e1znamy",
    "Admin Operation Logs": "Z\u00e1znamy administra\u010dn\u00edch operac\u00ed",
    "Admin access": "P\u0159\u00edstup spr\u00e1vce",
    "Admins": "Administr\u00e1to\u0159i",
    "All": "V\u0161e",
    "All Groups": "V\u0161echny skupiny",
    "All Libraries": "V\u0161echny knihovny",
    "All Notifications": "V\u0161echna upozorn\u011bn\u00ed",
    "All Public Links": "V\u0161echny ve\u0159ejn\u00e9 odkazy",
    "All file types": "V\u0161echny typy soubor\u016f",
    "Allow new user registrations. Uncheck this to prevent anyone from creating a new account.": "Povolit registrace nov\u00fdm u\u017eivatel\u016fm. Od\u0161krtn\u011bte tuto polo\u017eku pro zak\u00e1z\u00e1n\u00ed vytv\u00e1\u0159en\u00ed nov\u00fdch u\u017eivatelsk\u00fdch \u00fa\u010dt\u016f.",
    "Allow user to change library history settings": "Povolit u\u017eivatel\u016fm zm\u011bnu nastaven\u00ed historie knihovny",
    "Allow user to clean library trash": "Povolit u\u017eivateli vypr\u00e1zdnit ko\u0161 knihovny",
    "Allow user to create encrypted libraries": "Povolit u\u017eivatel\u016fm vytv\u00e1\u0159et \u0161ifrovan\u00e9 knihovny",
    "An integer that is greater than 0 or equal to -2.": "\u010c\u00edslo kter\u00e9 je v\u011bt\u0161\u00ed ne\u017e 0 nebo se rovn\u00e1 -2.",
    "An integer that is greater than or equal to 0.": "\u010c\u00edslo kter\u00e9 je v\u011bt\u0161\u00ed nebo rovno 0.",
    "An internal link is a link to a file or folder that can be accessed by users with read permission to the file or folder.": "Intern\u00ed odkaz sm\u011b\u0159uje na soubor nebo slo\u017eku u kter\u00e9 m\u00e1 u\u017eivatel opr\u00e1vn\u011bn\u00ed ke \u010dten\u00ed.",
    "Anonymous User": "Anonymn\u00ed u\u017eivatel",
    "App Name": "N\u00e1zev aplikace",
    "Are you sure to delete": "Opravdu smazat",
    "Are you sure to revoke access of user {placeholder} ?": "Opravdu chcete odebrat p\u0159\u00edstup u\u017eivateli {placeholder}?",
    "Are you sure you want to clear trash?": "Opravdu chcete vysypat ko\u0161?",
    "Are you sure you want to delete %s ?": "Skute\u010dn\u011b chcete smazat %s ?",
    "Are you sure you want to delete the notification ?": "Opravdu chcete vymazat ozn\u00e1men\u00ed ?",
    "Are you sure you want to delete the selected user(s) ?": "Jste si jisti, \u017ee chcete smazat vybran\u00e9 u\u017eivatele ?",
    "Are you sure you want to delete the share link?": "Opravdu chcete smazat sd\u00edlec\u00ed odkaz?",
    "Are you sure you want to delete these selected items?": "Opravdu chcete smazat tyto polo\u017eky?",
    "Are you sure you want to delete {placeholder} ?": "Skute\u010dn\u011b chcete smazat {placeholder}?",
    "Are you sure you want to delete {placeholder} completely?": "Opravdu chcete {placeholder} \u00fapln\u011b smazat?",
    "Are you sure you want to disconnect?": "Skute\u010dn\u011b se chcete odpojit?",
    "Are you sure you want to remove {placeholder} ?": "Opravdu chcete odebrat {placeholder}?",
    "Are you sure you want to reset the password of {placeholder} ?": "Opravdu chcete resetovat heslo u\u017eivatele {placeholder}?",
    "Are you sure you want to restore this library?": "Jste si jisti, \u017ee chcete obnovit tuto knihovnu?",
    "Are you sure you want to restore {placeholder}?": "Opravdu chcete obnovit {placeholder}?",
    "Are you sure you want to revoke the admin permission of {placeholder} ?": "Opravdu chcete zru\u0161it administr\u00e1torsk\u00e9 opr\u00e1vn\u011bn\u00ed u\u017eivatele {placeholder}?",
    "Are you sure you want to set {placeholder} as Admin?": "Opravdu chcete nastavit {placeholder} jako spr\u00e1vce?",
    "Are you sure you want to unlink this device?": "Opravdu chcete odpojit toto za\u0159\u00edzen\u00ed?",
    "Are you sure you want to unpublish this library?": "Opravdu chcete zru\u0161it zve\u0159ejn\u011bn\u00ed t\u00e9to knihovny?",
    "Are you sure you want to unshare {placeholder} ?": "Opravdu chcete zru\u0161it sd\u00edlen\u00ed {placeholder}?",
    "At server": "Na serveru",
    "Audio": "Audio",
    "Audit Admin": "Auditn\u00ed administr\u00e1tor",
    "Auto deletion": "Automatick\u00e9 maz\u00e1n\u00ed",
    "Automatically delete files that are not modified within certain days:": "Automaticky mazat soubory, kter\u00e9 nejsou zm\u011bn\u011bny b\u011bhem ur\u010dit\u00fdch dn\u00ed:",
    "Avatar": "Profilov\u00fd obr\u00e1zek",
    "Avatar:": "Profilov\u00fd obr\u00e1zek:",
    "Back": "Zp\u011bt",
    "Besides Write permission, user can also share the library.": "Krom\u011b opr\u00e1vn\u011bn\u00ed k z\u00e1pisu, u\u017eivatel m\u016f\u017ee tak\u00e9 sd\u00edlet knihovnu.",
    "Branding": "Obchodn\u00ed zna\u010dka",
    "Broken (please contact your administrator to fix this library)": "Po\u0161kozen\u00e1 (obra\u0165te se na spr\u00e1vce ohledn\u011b opravy t\u00e9to knihovny)",
    "Broken ({repo_id_placeholder})": "Po\u0161kozen\u00e9 ({repo_id_placeholder})",
    "By name ascending": "Podle jm\u00e9na vzestupn\u011b",
    "By name descending": "Podle jm\u00e9na sestupn\u011b",
    "By size ascending": "Podle velikosti vzestupn\u011b",
    "By size descending": "Podle velikosti sestupn\u011b",
    "By time ascending": "Podle \u010dasu vzestupn\u011b",
    "By time descending": "Podle \u010dasu sestupn\u011b",
    "Can not copy directory %(src)s to its subdirectory %(des)s": "Nemohu zkop\u00edrovat adres\u00e1\u0159 %(src)s do podadres\u00e1\u0159e %(des)s",
    "Can not move directory %(src)s to its subdirectory %(des)s": "Nemohu p\u0159esunout adres\u00e1\u0159 %(src)s do podadres\u00e1\u0159e %(des)s",
    "Cancel": "Zru\u0161it",
    "Cancel All": "Zru\u0161it v\u0161e",
    "Canceled.": "Zru\u0161eno.",
    "Change": "Zm\u011bnit",
    "Change Password": "Zm\u011bnit heslo",
    "Change Password of Library {placeholder}": "Zm\u011bnit heslo knihovny {placeholder}",
    "Changes": "Zm\u011bny",
    "Choose date": "Vyberte datum",
    "Clean": "Vy\u010distit",
    "Clean succeeded.": "\u010ci\u0161t\u011bn\u00ed bylo \u00fasp\u011b\u0161n\u00e9.",
    "Cleaned trash": "Vy\u010di\u0161t\u011bn\u00fd ko\u0161",
    "Clear": "Vy\u010distit",
    "Clear Trash": "Vysypat ko\u0161",
    "Clear files in trash and history\uff1a": "Vypr\u00e1zdnit ko\u0161 a historii: ",
    "Clients": "Klienti",
    "Close": "Zav\u0159\u00edt",
    "Close (Esc)": "Zav\u0159\u00edt (Esc)",
    "Column": "Sloupec",
    "Community Edition": "Komunitn\u00ed vyd\u00e1n\u00ed",
    "Confirm": "Potvrdit",
    "Confirm Password": "Potvrzen\u00ed hesla",
    "Connect": "P\u0159ipojit",
    "Contact Email": "Kontaktn\u00ed email",
    "Contact Email:": "Kontaktn\u00ed e-mail:",
    "Contact Information": "Kontaktn\u00ed informace",
    "Contact information is required.": "Jsou po\u017eadov\u00e1ny kontaktn\u00ed informace",
    "Content Scan Records": "Z\u00e1znamy skenu obsahu",
    "Copy": "Kop\u00edrovat",
    "Copy selected item(s) to:": "Zkop\u00edrovat ozna\u010denou polo\u017eku(ky) do:",
    "Copy {num} items": "Kop\u00edrovat {num} polo\u017eek",
    "Copy {placeholder} to": "Zkop\u00edrovat {placeholder} do",
    "Copy {placeholder} to:": "Kop\u00edrovat {placeholder} do:",
    "Copying %(name)s": "Kop\u00edrov\u00e1n\u00ed %(name)s",
    "Copying file %(index)s of %(total)s": "Kop\u00edrov\u00e1n\u00ed souboru %(index)s ze %(total)s",
    "Copyright Infringement": "Poru\u0161en\u00ed autorsk\u00fdch pr\u00e1v",
    "Count": "Po\u010det",
    "Create": "Vytvo\u0159it",
    "Create Group": "Vytvo\u0159it skupinu",
    "Create Library": "Vytvo\u0159it knihovnu",
    "Create Report": "Vy\u010distit report",
    "Create a draft from this file, instead of editing it directly.": "Vytvo\u0159it z tohoto souboru n\u00e1vrh m\u00edsto p\u0159\u00edm\u00e9 \u00fapravy.",
    "Create a new tag": "Vytvo\u0159it nov\u00fd \u0161t\u00edtek",
    "Created": "Vytvo\u0159eno",
    "Created At": "Vytvo\u0159eno",
    "Created Files": "Vytvo\u0159en\u00e9 soubory",
    "Created draft": "Vytvo\u0159en\u00fd koncept",
    "Created file": "Vytvo\u0159en\u00fd soubor",
    "Created folder": "Vytvo\u0159en\u00e1 slo\u017eka",
    "Created group {group_name}": "Skupina {group_name} byla vytvo\u0159ena",
    "Created library": "Vytvo\u0159en\u00e1 knihovna",
    "Created library {library_name} with {owner} as its owner": "Knihovna {library_name} vytvo\u0159ena s vlastn\u00edkem {owner}",
    "Created {n} files": "Vytvo\u0159eno {n} soubor\u016f",
    "Creator": "Vytvo\u0159il",
    "Current Connected Devices": "Aktu\u00e1ln\u011b p\u0159ipojen\u00e1 za\u0159\u00edzen\u00ed",
    "Current Library": "Aktu\u00e1ln\u00ed knihovna",
    "Current Path: ": "Aktu\u00e1ln\u00ed cesta: ",
    "Current Version": "Aktu\u00e1ln\u00ed verze",
    "Current path: ": "Aktu\u00e1ln\u00ed cesta: ",
    "Custom CSS": "Vlastn\u00ed CSS",
    "Custom file types": "Vlastn\u00ed typy soubor\u016f",
    "Daily Admin": "Denn\u00ed administr\u00e1tor",
    "Database": "Datab\u00e1ze",
    "Date": "Datum",
    "Date Invalid.": "Neplatn\u00fd datum",
    "Default": "V\u00fdchoz\u00ed",
    "Default Admin": "V\u00fdchoz\u00ed administr\u00e1tor",
    "Delete": "Smazat",
    "Delete Account": "Smazat \u00fa\u010det",
    "Delete Department": "Smazat odd\u011blen\u00ed",
    "Delete Expired Invitations": "Smazat pro\u0161l\u00e9 pozv\u00e1nky",
    "Delete File": "Smazat soubor",
    "Delete Folder": "Smazat slo\u017eku",
    "Delete Group": "Smazat skupinu",
    "Delete Institution": "Smazat instituci",
    "Delete Items": "Vymazat polo\u017eky",
    "Delete Library": "Smazat knihovnu",
    "Delete Member": "Smazat \u010dlena",
    "Delete Notification": "Smazat ozn\u00e1men\u00ed",
    "Delete Organization": "Smazat organizaci",
    "Delete T&C": "Smazat podm\u00ednky",
    "Delete Time": "\u010cas smaz\u00e1n\u00ed",
    "Delete User": "Smazat u\u017eivatele",
    "Delete Users": "Smazat u\u017eivatele",
    "Delete draft": "Smazat koncept",
    "Delete failed": "Smaz\u00e1n\u00ed selhalo",
    "Delete files from this device the next time it comes online.": "Smazat soubory z tohoto za\u0159\u00edzen\u00ed, a\u017e se p\u0159\u00ed\u0161t\u011b p\u0159ipoj\u00ed.",
    "Deleted": "Smaz\u00e1no",
    "Deleted Libraries": "Smazan\u00e9 knihovny",
    "Deleted Time": "\u010cas smaz\u00e1n\u00ed",
    "Deleted directories": "Smazan\u00e9 adres\u00e1\u0159e",
    "Deleted draft": "Smazan\u00fd koncept",
    "Deleted file": "Smazan\u00fd soubor",
    "Deleted files": "Smazan\u00e9 soubory",
    "Deleted folder": "Smazan\u00e1 slo\u017eka",
    "Deleted group {group_name}": "Skupina {group_name} byla smaz\u00e1na",
    "Deleted library": "Smazan\u00e1 knihovna",
    "Deleted library {library_name}": "Knihovna {library_name} byla smaz\u00e1na",
    "Deleted user {user}": "U\u017eivatel {user} byl smaz\u00e1n",
    "Departments": "Odd\u011blen\u00ed",
    "Description": "Popis",
    "Description is required": "Popis je povinn\u00fd",
    "Desktop": "Desktop",
    "Details": "Detaily",
    "Device": "Za\u0159\u00edzen\u00ed",
    "Device Name": "Jm\u00e9no za\u0159\u00edzen\u00ed",
    "Devices": "Za\u0159\u00edzen\u00ed",
    "Direct Download Link:": "P\u0159\u00edm\u00fd odkaz ke sta\u017een\u00ed:",
    "Direct download link is copied to the clipboard.": "P\u0159\u00edm\u00fd odkaz ke sta\u017een\u00ed zkop\u00edrov\u00e1n do schr\u00e1nky.",
    "Directory": "Adres\u00e1\u0159",
    "Disable Two-Factor Authentication": "Vypnout dvoufaktorovou autentizaci",
    "Disconnect": "Odpojit",
    "Do not automatically delete files": "Neodstra\u0148ovat soubory automaticky\u00a0",
    "Document": "Dokument",
    "Document convertion failed.": "Konverze dokumentu selhala",
    "Documents": "Dokumenty",
    "Don't ignore": "Neignorujte",
    "Don't keep history": "Neukl\u00e1dat historii",
    "Don't replace": "Nenahrazovat",
    "Don't send emails": "Neodes\u00edlat emaily",
    "Download": "St\u00e1hnout",
    "Download an example file": "St\u00e1hnout uk\u00e1zkov\u00fd soubor",
    "Download and upload": "St\u00e1hnout a nahr\u00e1t",
    "Draft": "Koncept",
    "Draft is a way to let you collaborate with others on files. You can create a draft from a file, edit the draft and then ask for a review. The original file will be updated only after the draft has been reviewed.": "Koncept je zp\u016fsob, jak v\u00e1m umo\u017en\u00ed spolupracovat s ostatn\u00edmi na souborech. M\u016f\u017eete vytvo\u0159it koncept ze souboru, upravit koncept a pot\u00e9 po\u017e\u00e1dat o kontrolu. P\u016fvodn\u00ed soubor bude aktualizov\u00e1n a\u017e po revizi konceptu.",
    "Drafts": "N\u00e1vrhy",
    "Drag and drop files or folders here.": "Sem p\u0159et\u00e1hn\u011bte soubory nebo slo\u017eky.",
    "Edit": "Upravit",
    "Edit File": "Upravit soubor",
    "Edit failed": "Editace selhala.",
    "Edit labels": "Upravit \u0161t\u00edtky",
    "Edit on cloud and download": "Upravit v cloudu a st\u00e1hnout",
    "Edit on cloud only": "Upravit pouze na cloudu",
    "Edit succeeded": "Editace byla \u00fasp\u011b\u0161n\u00e1",
    "Edit succeeded.": "\u00dapravy prob\u011bhly \u00fasp\u011b\u0161n\u011b.",
    "Email": "Email",
    "Email Notification": "Emailov\u00e9 notifikace",
    "Email is invalid.": "Neplatn\u00fd E-mail.",
    "Emails": "Emaily",
    "Emails, separated by ','": "E-maily, odd\u011blovan\u00e9 \u201e,\u201c (\u010d\u00e1rka)",
    "Empty file upload result": "Pr\u00e1zdn\u00fd v\u00fdsledek nahr\u00e1v\u00e1n\u00ed souboru",
    "Enable Two-Factor Authentication": "Zapnout dvoufaktorovou autentizaci",
    "Enable system admin to add Terms and Conditions, and all users will have to accept the terms.": "Umo\u017en\u00ed administr\u00e1torovi p\u0159idat pravidla a podm\u00ednky, se kter\u00fdmi budou u\u017eivatel\u00e9 muset souhlasit.",
    "Enable two factor authentication": "Zapnout dvoufaktorovou autentizaci",
    "Enable users to share libraries to any groups in the system.": "Povolit u\u017eivatel\u016fm sd\u00edlen\u00ed knihoven do jak\u00e9koliv skupiny v syst\u00e9mu.",
    "Encrypt": "\u0160ifrovat",
    "Encrypted library": "\u0160ifrovan\u00e1 knihovna",
    "End date": "Datum ukon\u010den\u00ed",
    "Enter characters to start searching": "Za\u010dn\u011bte hledat zad\u00e1n\u00edm znak\u016f",
    "Error": "Chyba",
    "Errors": "Chyby",
    "Exit Institution Admin": "Ukon\u010dete spr\u00e1vu instituce",
    "Exit Organization Admin": "Opustit spr\u00e1vu organizace",
    "Exit System Admin": "Odej\u00edt z administrace syst\u00e9mu",
    "Expiration": "Skon\u010den\u00ed platnosti",
    "Expiration Date:": "Datum expirace:",
    "Expiration days": "Dny vypr\u0161en\u00ed platnosti",
    "Expiration time": "Doba platnosti",
    "Expired": "Vypr\u0161en\u00fd",
    "Expired at": "Platnost skon\u010dila",
    "Export Excel": "Export do Excelu",
    "Extensions of text files that can be online previewed, each suffix is separated by a comma.": "P\u0159\u00edpony textov\u00fdch soubor\u016f, kter\u00e9 m\u016f\u017eou b\u00fdt zobrazeny online. Ka\u017ed\u00e1 p\u0159\u00edpona je odd\u011blena \u010d\u00e1rkou.",
    "Failed": "Chyba",
    "Failed to add {email_placeholder}: {error_msg_placeholder}": "Chyba p\u0159i p\u0159id\u00e1v\u00e1n\u00ed {email_placeholder}: {error_msg_placeholder}",
    "Failed to copy %(name)s": "Chyba p\u0159i kop\u00edrov\u00e1n\u00ed %(name)s",
    "Failed to copy %(name)s and %(amount)s other item(s).": "Chyba p\u0159i kop\u00edrov\u00e1n\u00ed %(name)s a %(amount)s dal\u0161\u00edch polo\u017eky(ek).",
    "Failed to copy %(name)s.": "Chyba p\u0159i kop\u00edrov\u00e1n\u00ed %(name)s.",
    "Failed to copy files to another library.": "Nepoda\u0159ilo se zkop\u00edrovat soubory do jin\u00e9 knihovny.",
    "Failed to delete %(name)s and %(amount)s other items.": "Smaz\u00e1n\u00ed selhalo %(name)s a %(amount)s dal\u0161\u00edch polo\u017eek.",
    "Failed to delete %(name)s and 1 other item.": "Smaz\u00e1n\u00ed selhalo: %(name)s a 1 dal\u0161\u00edch polo\u017eek.",
    "Failed to delete %(name)s.": "Smaz\u00e1n\u00ed selhalo: %(name).",
    "Failed to delete %(virus_file) from library %(library): %(error_msg)": "Nepoda\u0159ilo se odstranit %(virus_file) z knihovny %(library): %(error_msg)",
    "Failed to delete draft %(draft)s.": "Ne\u00fasp\u011b\u0161n\u011b smazan\u00fd n\u00e1vrh %(draft)s.",
    "Failed to delete {name}": "Chyba p\u0159i odstran\u011bn\u00ed {name}",
    "Failed to delete {name}.": "Chyba p\u0159i odstran\u011bn\u00ed {name}.",
    "Failed to get update url": "Chyba p\u0159i z\u00edsk\u00e1v\u00e1n\u00ed url aktualizace",
    "Failed to get upload url": "Chyba p\u0159i z\u00edsk\u00e1v\u00e1n\u00ed url nahr\u00e1v\u00e1n\u00ed",
    "Failed to ignore %(virus_file) from library %(library): %(error_msg)": "Nepoda\u0159ilo se ignorovat %(virus_file) z knihovny %(library): %(error_msg)",
    "Failed to move %(name)s": "Chyba p\u0159i p\u0159esunu %(name)s",
    "Failed to move %(name)s and %(amount)s other item(s).": "Chyba p\u0159i p\u0159esunu %(name)s a %(amount)s dal\u0161\u00edch polo\u017eky(ek).",
    "Failed to move %(name)s.": "Chyba p\u0159i p\u0159esunu %(name)s.",
    "Failed to move files to another library.": "Nepoda\u0159ilo se p\u0159esunout soubory do jin\u00e9 knihovny.",
    "Failed to move {name}.": "Chyba p\u0159i p\u0159esunu {name}.",
    "Failed to publish draft %(draft)s.": "Ne\u00fasp\u011b\u0161n\u011b zve\u0159ejn\u011bn\u00fd n\u00e1vrh %(draft)s.",
    "Failed to send to {email_placeholder}: {errorMsg_placeholder}": "P\u0159i odes\u00edl\u00e1n\u00ed na {email_placeholder} nastala chyba: {errorMsg_placeholder}",
    "Failed to send to {placeholder}": "Chyba p\u0159i odes\u00edl\u00e1n\u00ed do {placeholder}",
    "Failed to unshare {name}": "Nepoda\u0159ilo se zru\u0161it sd\u00edlen\u00ed {name}",
    "Failed.": "Chyba.",
    "Failed. Please check the network.": "Chyba. Pros\u00edm zkontrolujte s\u00ed\u0165.",
    "Favorites": "Obl\u00edben\u00e9",
    "File": "Soubor",
    "File Access": "P\u0159\u00edstup k soubor\u016fm",
    "File Operations": "Souborov\u00e9 operace",
    "File Scan": "File Scan",
    "File Types": "Typy soubor\u016f",
    "File Update": "\u00daprava soubor\u016f",
    "File Upload": "Nahr\u00e1t soubor",
    "File Upload canceled": "Nahr\u00e1v\u00e1n\u00ed souboru zru\u0161eno",
    "File Upload complete": "Nahr\u00e1v\u00e1n\u00ed souboru dokon\u010deno",
    "File Upload failed": "Nahr\u00e1v\u00e1n\u00ed souboru selhalo",
    "File Uploading...": "Nahr\u00e1v\u00e1n\u00ed souboru...",
    "File already exists.": "Soubor ji\u017e existuje.",
    "File does not exist.": "Soubor neexistuje.",
    "File download is disabled: the share link traffic of owner is used up.": "Sta\u017een\u00ed souboru je vypnuto: Datov\u00fd limit sd\u00edlen\u00e9ho odkazu vlastn\u00edka byl vy\u010drp\u00e1n.",
    "File extensions can only be {placeholder}.": "P\u0159\u00edpony souboru mohou b\u00fdt pouze {placeholder}.",
    "File is locked": "Soubor je uzam\u010den",
    "File is locked by others.": "Soubor je uzam\u010den ostatn\u00edmi.",
    "File is too big": "Soubor je p\u0159\u00edli\u017e velk\u00fd",
    "File is too small": "Soubor je p\u0159\u00edli\u017e mal\u00fd",
    "File size is too large.": "Velikost souboru je p\u0159\u00edli\u0161 velk\u00e1.",
    "File size should be smaller than {max_size_placeholder}.": "Velikost souboru by m\u011bla b\u00fdt men\u0161\u00ed ne\u017e {max_size_placeholder}.",
    "Files": "Soubory",
    "Filetype not allowed": "Typ souboru nen\u00ed povolen",
    "Folder": "Slo\u017eka",
    "Folder Permission": "Opr\u00e1vn\u011bn\u00ed slo\u017eky",
    "Folder does not exist.": "Slo\u017eka neexistuje.",
    "Folder upload is limited to Chrome, Firefox 50+, and Microsoft Edge.": "Nahr\u00e1v\u00e1n\u00ed slo\u017eek je omezeno na Chrome, Firefox 50+ a Microsoft Edge.",
    "Folders": "Slo\u017eky",
    "Force user to change password when account is newly added or reset by admin": "P\u0159inutit u\u017eivatele ke zm\u011bn\u011b hesla, pokud jsou vytvo\u0159eni administr\u00e1torem nebo jim administr\u00e1tor heslo resetoval",
    "Force user to use a strong password when sign up or change password.": "Vy\u017eadovat po u\u017eivatel\u00edch pou\u017e\u00edvat siln\u00e9 hesla kdy\u017e se p\u0159ihl\u00e1s\u00ed nebo si m\u011bn\u00ed heslo.",
    "Freeze user account when failed login attempts exceed limit.": "Zmrazit u\u017eivatelsk\u00fd \u00fa\u010det po dosa\u017een\u00ed maxim\u00e1ln\u00edho po\u010dtu pokus\u016f o p\u0159ihl\u00e1\u0161en\u00ed.",
    "Generate": "Generovat",
    "Global Address Book": "Glob\u00e1ln\u00ed adres\u00e1\u0159",
    "Go to Library": "J\u00edt do knihovny",
    "Greater than or equal to {minDays_placeholder} days": "V\u011bt\u0161\u00ed nebo rovno {minDays_placeholder} dn\u00ed",
    "Grid": "M\u0159\u00ed\u017eka",
    "Group": "Skupina",
    "Group Permission": "Skupinov\u00e1 opr\u00e1vn\u011bn\u00ed",
    "Group not found": "Skupina nenalezena",
    "Groups": "Skupiny",
    "Guest": "Host",
    "Handled": "Ovl\u00e1d\u00e1no",
    "Help": "Pomoc",
    "Hide": "Skr\u00fdt",
    "History": "Historie",
    "History Setting": "Nastaven\u00ed historie",
    "History Versions": "Historie verz\u00ed",
    "IP": "IP",
    "If turn on, the desktop clients will not be able to sync a folder outside the default Seafile folder.": "Pokud bude zapnut\u00e9, desktopov\u00ed klienti nebudou schopni synchronizovat slo\u017eky mimo v\u00fdchoz\u00ed Seafile slo\u017eku. ",
    "If you don't have any device with you, you can access your account using backup codes.": "Pokud nem\u00e1te u sebe \u017e\u00e1dn\u00e9 za\u0159\u00edzen\u00ed, m\u016f\u017eete p\u0159isupovat k Va\u0161emu \u00fa\u010dtu pomoc\u00ed z\u00e1lo\u017en\u00edch k\u00f3d\u016f.",
    "Ignore": "Ignorovat",
    "Ignored": "Ignorov\u00e1no",
    "Image": "Obr\u00e1zek",
    "Images": "Obr\u00e1zky",
    "Import Members": "Importovat \u010dleny",
    "Import Users": "Importovat u\u017eivatele",
    "Import users": "Importovat u\u017eivatele",
    "Import users from a .xlsx file": "Importovat u\u017eivatele z XLSX souboru",
    "In all libraries": "Ve v\u0161ech knihovn\u00e1ch",
    "Inactive": "Neaktivn\u00ed",
    "Indexing...": "Indexov\u00e1n\u00ed...",
    "Info": "Info",
    "Input file extensions here, separate with ','": "Sem vlo\u017ete p\u0159\u00edponu souboru odd\u011blenou ','",
    "Institution": "Instituce",
    "Institution Admin": "Spr\u00e1vce organizace",
    "Institutions": "Instituce",
    "Internal Link": "Intern\u00ed odkaz",
    "Internal Server Error": "Vnit\u0159n\u00ed chyba serveru",
    "Internal error. Failed to copy %(name)s and %(amount)s other item(s).": "Intern\u00ed chyba. Chyba p\u0159i kop\u00edrov\u00e1n\u00ed %(name)s a %(amount)s dal\u0161\u00ed polo\u017eka(y).",
    "Internal error. Failed to copy %(name)s.": "Intern\u00ed chyba. Chyba p\u0159i kop\u00edrov\u00e1n\u00ed %(name)s.",
    "Internal error. Failed to move %(name)s and %(amount)s other item(s).": "Intern\u00ed chyba. Chyba p\u0159i p\u0159esunu %(name)s a %(amount)s dal\u0161\u00ed polo\u017eka(y).",
    "Internal error. Failed to move %(name)s.": "Intern\u00ed chyba. Chyba p\u0159i p\u0159esunu %(name)s.",
    "Internal link has been copied to clipboard": "Intern\u00ed odkaz byl zkop\u00edrov\u00e1n do schr\u00e1nky",
    "Invalid destination path": "Neplatn\u00e1 c\u00edlov\u00e1 cesta",
    "Invalid file size range.": "Neplatn\u00fd rozsah velikosti souboru",
    "Invalid filename.": "Chybn\u00e9 jm\u00e9no souboru.",
    "Invalid month, should be yyyymm.": "Neplatn\u00fd m\u011bs\u00edc, form\u00e1t je RRRRMM.",
    "Invitations": "Pozv\u00e1nky",
    "Invite Guest": "Pozvat hosta",
    "Invite Time": "\u010cas pozv\u00e1n\u00ed",
    "Invited at": "Pozv\u00e1n v",
    "Inviter": "Hostilel",
    "It is required.": "Vy\u017eadov\u00e1no.",
    "It may take some time, please wait.": "M\u016f\u017ee to chv\u00edli trvat, po\u010dkejte pros\u00edm.",
    "Just now": "Pr\u00e1v\u011b te\u010f",
    "Keep full history": "Ponechat v\u0161echnu historii",
    "LDAP": "LDAP",
    "LDAP(imported)": "LDAP(importov\u00e1no)",
    "Label": "\u0160t\u00edtek",
    "Label Current State": "Aktu\u00e1ln\u00ed stav \u0161t\u00edtku",
    "Labels": "\u0160t\u00edtky",
    "Language": "Jazyk",
    "Language Setting": "Nastaven\u00ed jazyka",
    "Last Access": "Posledn\u00ed p\u0159\u00edstup",
    "Last Login": "Posledn\u00ed p\u0159ihl\u00e1\u0161en\u00ed",
    "Last Update": "Posledn\u00ed aktualizace",
    "Last modified by": "Posledn\u00ed \u00fapravu provedl",
    "Leave": "Opustit",
    "Leave Group": "Opustit skupinu",
    "Leave Share": "Ponechat sd\u00edlen\u00ed",
    "Less than or equal to {maxDays_placeholder} days": "Men\u0161\u00ed nebo rovno {maxDays_placeholder} dn\u00ed",
    "Libraries": "Knihovny",
    "Library": "Knihovna",
    "Library Type": "Typ knihovny",
    "Library can not be shared to owner.": "Knihovna nem\u016f\u017ee b\u00fdt sd\u00edlena jej\u00edmu vlastn\u00edkovi.",
    "Limits": "Limity",
    "Link": "Odkaz",
    "Link has been copied to clipboard": "Odkaz byl zkop\u00edrov\u00e1n do schr\u00e1nky",
    "Link:": "Odkaz:",
    "Linked Devices": "Sp\u00e1rovan\u00e1 za\u0159\u00edzen\u00ed",
    "Links": "Odkazy",
    "List": "Seznam",
    "List your account in global address book, so that others can find you by typing your name.": "Zapi\u0161te sv\u016fj \u00fa\u010det do glob\u00e1ln\u00edho adres\u00e1\u0159e aby V\u00e1s ostatn\u00ed mohli naj\u00edt pomoc\u00ed Va\u0161eho jm\u00e9na.",
    "Loading failed": "Nahr\u00e1v\u00e1n\u00ed selhalo",
    "Loading...": "Nahr\u00e1v\u00e1m...",
    "Local draft": "M\u00edstn\u00ed koncept",
    "Local draft saved": "M\u00edstn\u00ed koncept byl ulo\u017een",
    "Location": "Um\u00edst\u011bn\u00ed",
    "Lock": "Z\u00e1mek",
    "Log out": "Odhl\u00e1stit",
    "Login": "P\u0159ihl\u00e1\u0161en\u00ed",
    "Login Background Image": "Pozad\u00ed p\u0159ihla\u0161ovac\u00ed obrazovky",
    "Logs": "Logy",
    "Manage Members": "Spravovat \u010dleny",
    "Manage group members": "Spravovat \u010dleny skupiny",
    "Mark all read": "Ozna\u010dit v\u0161e jako p\u0159e\u010dten\u00e9",
    "Max number of files exceeded": "Maxim\u00e1ln\u00ed po\u010det soubor\u016f p\u0159ekro\u010den",
    "Member": "\u010clen",
    "Members": "\u010clenov\u00e9",
    "Message": "Zpr\u00e1va",
    "Message (optional):": "Zpr\u00e1va(voliteln\u00e9):",
    "Mobile": "Mobiln\u00ed",
    "Modification Details": "Detaily zm\u011bn",
    "Modified": "Upraven",
    "Modified files": "Upraven\u00e9 soubory",
    "Modifier": "Upravil",
    "Modify": "Upravit",
    "Month:": "M\u011bs\u00edc:",
    "Monthly User Traffic": "M\u011bs\u00ed\u010dn\u00ed u\u017eivatelsk\u00e9 vyu\u017eit\u00ed",
    "More": "V\u00edce",
    "More Operations": "V\u00edce operac\u00ed",
    "Move": "P\u0159esunout",
    "Move selected item(s) to:": "P\u0159esunout ozna\u010denou polo\u017eku(ky) do:",
    "Move {num} items": "P\u0159esunout {num} polo\u017eek",
    "Move {placeholder} to": "P\u0159esunout {placeholder} do",
    "Move {placeholder} to:": "P\u0159esun {placeholder} do:",
    "Moved file": "P\u0159esunut\u00fd soubor",
    "Moved folder": "P\u0159esunut\u00e1 slo\u017eka",
    "Moving %(name)s": "P\u0159esunov\u00e1n\u00ed %(name)s",
    "Moving file %(index)s of %(total)s": "P\u0159esun souboru %(index)s z %(total)s",
    "My Groups": "Moje skupiny",
    "My Libraries": "Moje knihovny",
    "Name": "N\u00e1zev",
    "Name is required": "Vy\u017eadov\u00e1no jm\u00e9no",
    "Name is required.": "Jm\u00e9no je vy\u017eadov\u00e1no.",
    "Name should not include '/'.": "N\u00e1zev by nem\u011bl obsahovat \u201e/\u201c.",
    "Name(optional)": "Jm\u00e9no (voliteln\u00e9)",
    "Network error": "Chyba s\u00edt\u011b",
    "New": "Nov\u00fd",
    "New Department": "Nov\u00e9 odd\u011blen\u00ed",
    "New Department Library": "Nov\u00e1 knihovna pro odd\u011blen\u00ed.",
    "New Draft": "Nov\u00fd n\u00e1vrh",
    "New Excel File": "Nov\u00fd soubor Excelu",
    "New File": "Nov\u00fd soubor",
    "New Folder": "Nov\u00e1 slo\u017eka",
    "New Group": "Nov\u00e1 skupina",
    "New Library": "Nov\u00e1 knihovna",
    "New Markdown File": "Nov\u00fd Markdown soubor",
    "New Password": "Nov\u00e9 heslo",
    "New Password Again": "Nov\u00e9 heslo znovu",
    "New PowerPoint File": "Nov\u00fd soubor PowerPointu",
    "New Sub-department": "Nov\u00e9 pododd\u011blen\u00ed",
    "New Tag": "Nov\u00fd \u0161t\u00edtek",
    "New Wiki": "Nov\u00e1 Wiki str\u00e1nka",
    "New Word File": "Nov\u00fd soubor Wordu",
    "New directories": "Nov\u00e9 adres\u00e1\u0159e",
    "New file name": "Nov\u00fd n\u00e1zev souboru",
    "New files": "Nov\u00e9 soubory",
    "New folder name": "Nov\u00fd n\u00e1zev slo\u017eky",
    "New password has been sent to your email {mail}. Please check your mailbox. If you don\u2019t receive the password, please check if your email address is properly configured.": "Nov\u00e9 heslo bylo zasl\u00e1no na V\u00e1\u0161 e-mail {mail}. Zkontrolujte pros\u00edm Va\u0161i doru\u010denou po\u0161tu. Pokud jste heslo neobdr\u017eeli, zkontrolujte pros\u00edm zda m\u00e1te spr\u00e1vn\u011b nastavenou e-mailovou adresu.",
    "New password is too short": "Nov\u00e9 heslo je p\u0159\u00edli\u0161 kr\u00e1tk\u00e9",
    "New passwords don't match": "Zad\u00e1n\u00ed nov\u00e9ho hesla se neshoduj\u00ed",
    "Next": "Dal\u0161\u00ed",
    "Next (Right arrow key)": "N\u00e1sleduj\u00edc\u00ed (\u0161ipkou vpravo)",
    "No": "Ne",
    "No Admin login logs": "\u017d\u00e1dn\u00e9 z\u00e1znamy o p\u0159ihl\u00e1\u0161en\u00edch spr\u00e1vce",
    "No Admin operation logs": "\u017d\u00e1dn\u00e9 protokoly operac\u00ed spr\u00e1vce",
    "No connected devices": "\u017d\u00e1dn\u00e1 p\u0159ipojen\u00e1 za\u0159\u00edzen\u00ed",
    "No deleted libraries": "\u017d\u00e1dn\u00e9 smazan\u00e9 knihovny",
    "No departments": "\u017d\u00e1dn\u00e9 odd\u011blen\u00ed",
    "No draft yet": "Zat\u00edm bez n\u00e1vrh\u016f",
    "No favorites": "\u017d\u00e1dn\u00e9 obl\u00edben\u00e9",
    "No file access logs": "\u017d\u00e1dn\u00e9 protokoly p\u0159\u00edstupu k soubor\u016fm",
    "No file update logs": "\u017d\u00e1dn\u00e9 protokoly o aktualizaci soubor\u016f",
    "No folders shared": "\u017d\u00e1dn\u00e9 sd\u00edlen\u00e9 slo\u017eky",
    "No groups": "\u017d\u00e1dn\u00e9 skupiny",
    "No guest invitations": "\u017d\u00e1dn\u00e9 pozv\u00e1nky host\u016f",
    "No invitations": "\u017d\u00e1dn\u00e9 pozv\u00e1nky",
    "No libraries": "\u017d\u00e1dn\u00e9 knihovny",
    "No libraries have been shared directly with you. A shared library can be shared with full or restricted permission. If you need access to a library owned by another user, ask the user to share the library with you.": "P\u0159\u00edmo s v\u00e1mi nejsou sd\u00edleny \u017e\u00e1dn\u00e9 knihovny. Sd\u00edlenou knihovnu lze sd\u00edlet s pln\u00fdm nebo omezen\u00fdm opr\u00e1vn\u011bn\u00edm. Pokud pot\u0159ebujete p\u0159\u00edstup do knihovny vlastn\u011bn\u00e9 jin\u00fdm u\u017eivatelem, po\u017e\u00e1dejte u\u017eivatele, aby s v\u00e1mi sd\u00edlel knihovnu.",
    "No libraries have been shared with this group yet. A library shared with a group can be accessed by all group members. You can share a library with a group in \"My Libraries\". You can also create a new library to be shared with this group by clicking the \"New Library\" button in the menu bar.": "S touto skupinou zat\u00edm nejsou sd\u00edleny \u017e\u00e1dn\u00e9 knihovny. Ke knihovn\u011b sd\u00edlen\u00e9 se skupinou maj\u00ed p\u0159\u00edstup v\u0161ichni \u010dlenov\u00e9 skupiny. Knihovnu m\u016f\u017eete sd\u00edlet se skupinou v \u010d\u00e1sti \u201eMoje knihovny\u201c. M\u016f\u017eete tak\u00e9 vytvo\u0159it novou knihovnu, kterou chcete sd\u00edlet s touto skupinou, kliknut\u00edm na tla\u010d\u00edtko \u201eNov\u00e1 knihovna\u201c na panelu nab\u00eddek.",
    "No libraries have been shared with you": "Nejsou s V\u00e1mi sd\u00edleny \u017e\u00e1dn\u00e9 knihovny",
    "No libraries have been shared with you from other servers.": "Z jin\u00fdch server\u016f s v\u00e1mi nebyly sd\u00edleny \u017e\u00e1dn\u00e9 knihovny.",
    "No libraries shared": "Nejsou sd\u00edleny \u017e\u00e1dn\u00e9 knihovny",
    "No libraries shared with this group": "S touto skupinou nejsou sd\u00edleny \u017e\u00e1dn\u00e9 knihovny",
    "No linked devices": "\u017d\u00e1dn\u00e1 p\u0159ipojen\u00e1 za\u0159\u00edzen",
    "No login logs": "\u017d\u00e1dn\u00e9 p\u0159ihla\u0161ovac\u00ed protokoly",
    "No matches": "\u017d\u00e1dn\u00e9 shody",
    "No members": "\u017d\u00e1dn\u00ed \u010dlenov\u00e9",
    "No notifications": "\u017d\u00e1dn\u00e9 ozn\u00e1men\u00ed",
    "No permission logs": "\u017d\u00e1dn\u00e9 protokoly opr\u00e1vn\u011bn\u00ed",
    "No preview": "Bez n\u00e1hledu",
    "No public libraries": "\u017d\u00e1dn\u00e9 ve\u0159ejn\u00e9 knihovny",
    "No public libraries have been created yet. A public library is accessible by all users. You can create a public library by clicking the \"Add Library\" button in the menu bar.": "Dosud nebyly vytvo\u0159eny \u017e\u00e1dn\u00e9 ve\u0159ejn\u00e9 knihovny. Ve\u0159ejn\u00e1 knihovna je p\u0159\u00edstupn\u00e1 v\u0161em u\u017eivatel\u016fm. Ve\u0159ejnou knihovnu m\u016f\u017eete vytvo\u0159it kliknut\u00edm na tla\u010d\u00edtko \u201eP\u0159idat knihovnu\u201c na panelu nab\u00eddek.",
    "No published libraries": "\u017d\u00e1dn\u00e9 zve\u0159ejn\u011bn\u00e9 knihovny",
    "No result": "\u017d\u00e1dn\u00fd v\u00fdsledek",
    "No results matching.": "\u017d\u00e1dn\u00fd v\u00fdsledek",
    "No share links": "\u017d\u00e1dn\u00e9 odkazy pro sd\u00edlen\u00ed",
    "No shared libraries": "\u017d\u00e1dn\u00e9 sd\u00edlen\u00e9 knihovny",
    "No sub-departments": "\u017d\u00e1dn\u00e9 pododd\u011blen\u00ed",
    "No sync errors": "\u017d\u00e1dn\u00e9 chyby synchronizace",
    "No terms and conditions": "\u017d\u00e1dn\u00e1 pravidla a podm\u00ednky",
    "No upload links": "\u017d\u00e1dn\u00e9 odkazy pro nahr\u00e1v\u00e1n\u00ed",
    "None": "\u017d\u00e1dn\u00fd",
    "Note: Settings via web interface are saved in database table (seahub-db/constance_config). They have a higher priority over the settings in config files.": "Pozn\u00e1mka: nastaven\u00ed p\u0159es webov\u00e9 rozhran\u00ed jsou ulo\u017eena v datab\u00e1zi, v tabulce (seahub-db/constance_config). Maj\u00ed vy\u0161\u0161\u00ed prioritu ne\u017e nastaven\u00ed v konfigura\u010dn\u00edch souborech.",
    "Notification Detail": "Detail upozorn\u011bn\u00ed",
    "Notifications": "Upozorn\u011bn\u00ed",
    "Number of days that keep user sign in.": "Po\u010det dn\u00ed po, kter\u00e9 z\u016fstanete p\u0159ihl\u00e1\u0161en.",
    "Number of groups": "Po\u010det skupin",
    "Off": "Vypnuto",
    "Old Password": "Star\u00e9 heslo",
    "On": "Zapnuto",
    "Online Preview": "Online n\u00e1hled",
    "Online Read-Only": "Online pouze pro \u010dten\u00ed",
    "Online Read-Only folder": "Online slo\u017eka pouze pro \u010dten\u00ed",
    "Online Read-Only library": "Online knihovna pouze pro \u010dten\u00ed",
    "Online Read-Write": "Online \u010dten\u00ed a z\u00e1pis",
    "Online Read-Write folder": "Online slo\u017eka pro \u010dten\u00ed a z\u00e1pis",
    "Online Read-Write library": "Online knihovna pro \u010dten\u00ed a z\u00e1pis",
    "Online view is not applicable to this file format": "Online zobrazen\u00ed nen\u00ed u tohoto typu souboru podporovan\u00e9",
    "Only Show": "Pouze zobrazit",
    "Only an extension there, please input a name.": "Pouze roz\u0161\u00ed\u0159en\u00ed, pros\u00edm zadejte jm\u00e9no.",
    "Only keep a period of history:": "Pouze ponechat obdob\u00ed historie:",
    "Open in New Tab": "Oteb\u0159\u00edt na nov\u00e9 kart\u011b",
    "Open parent directory": "Otev\u0159\u00edt rodi\u010dovsk\u00fd adres\u00e1\u0159",
    "Open parent folder": "Otev\u0159\u00edt rodi\u010dovsk\u00fd adres\u00e1\u0159",
    "Open via Client": "Otev\u0159\u00edt pomoc\u00ed klienta",
    "Operation": "Operace",
    "Operation succeeded.": "Operace byla \u00fasp\u011b\u0161n\u00e1",
    "Operations": "Operace",
    "Organization": "Organizace",
    "Organization Admin": "Spr\u00e1vce organizace",
    "Organizations": "Organizace",
    "Other": "Ostatn\u00ed",
    "Other Libraries": "Ostatn\u00ed knihovny",
    "Out of quota.": "Nedostatek \u00falo\u017en\u00e9ho prostoru - mimo kv\u00f3tu.",
    "Owned Libraries": "Vlastn\u011bn\u00e9 knihovny",
    "Owner": "Vlastn\u00edk",
    "Owner can use admin panel in an organization, must be a new account.": "Vlastn\u00edk m\u016f\u017ee pou\u017e\u00edt panel v organizaci, mus\u00ed b\u00fdt nov\u00fd \u00fa\u010det.",
    "Packaging...": "Balen\u00ed\u2026",
    "Password": "Heslo",
    "Password again": "Heslo znovu",
    "Password is required.": "Heslo je vy\u017eadov\u00e1no.",
    "Password is too short": "Heslo je p\u0159\u00edli\u017e kr\u00e1tk\u00e9",
    "Password:": "Heslo:",
    "Passwords do not match.": "Hesla nesouhlas\u00ed.",
    "Passwords don't match": "Hesla se neshoduj\u00ed",
    "Path": "Popis um\u00edst\u011bn\u00ed",
    "Per 4 hours": "Ka\u017ed\u00e9 4 hodiny",
    "Per day": "Ka\u017ed\u00fd den",
    "Per hour": "Ka\u017edou hodinu",
    "Per week": "Ka\u017ed\u00fd t\u00fdden",
    "Permission": "Opr\u00e1vn\u011bn\u00ed",
    "Permission denied": "P\u0159\u00edstup odep\u0159en",
    "Permission denied. Please try {placeholder-left}login again.{placeholder-right}": "P\u0159\u00edstup byl odep\u0159en. Pros\u00edm zkuste {placeholder-left}p\u0159ihl\u00e1\u0161en\u00ed znovu.{placeholder-right}",
    "Permission error": "Chyba opr\u00e1vn\u011bn\u00ed",
    "Permission:": "Opr\u00e1vn\u011bn\u00ed:",
    "Platform": "Platforma",
    "Please check the network.": "Pros\u00edm, zkontrolujte s\u00ed\u0165.",
    "Please choose a .xlsx file.": "Pros\u00edm vyberte XLSX soubor",
    "Please choose an image file.": "Zvolte soubor s obr\u00e1zkem.",
    "Please enter 1 or more character": "Zadejte pros\u00edm 1 a v\u00edce znak\u016f",
    "Please enter a new password": "Zadejte nov\u00e9 heslo",
    "Please enter a non-negative integer": "Vlo\u017ete pros\u00edm nez\u00e1porn\u00e9 cel\u00e9 \u010d\u00edslo",
    "Please enter a positive integer": "Zadejte kladn\u00e9 cel\u00e9 \u010d\u00edslo",
    "Please enter days": "Pros\u00edm zadejte dny",
    "Please enter days.": "Pros\u00edm zadejte dn\u016f.",
    "Please enter password": "Zadejte pros\u00edm heslo",
    "Please enter the new password again": "Zopakujte zad\u00e1n\u00ed nov\u00e9ho hesla",
    "Please enter the old password": "Zadejte p\u016fvodn\u00ed heslo",
    "Please enter the password again": "Zadejte pros\u00edm heslo znovu",
    "Please enter valid days": "Pros\u00edm zadejte platn\u00e9 dny",
    "Please input at least an email.": "Pros\u00edm zadejte nejm\u00e9n\u011b email.",
    "Please select a library to share.": "Vyberte pros\u00edm knihovnu ke sd\u00edlen\u00ed",
    "Please upload files less than {placeholder}M": "Nahrajte soubory men\u0161\u00ed ne\u017e {placeholder}M",
    "Please upload no more than {maxFiles} files at a time.": "Nahr\u00e1vejte v\u00edce ne\u017e {maxFiles} soubor\u016f najednou.",
    "Preparing to upload...": "P\u0159\u00edprava pro nahr\u00e1v\u00e1n\u00ed...",
    "Preview and download": "Zobrazit a st\u00e1hnout",
    "Preview only": "Pouze zobrazit",
    "Previous": "P\u0159edchoz\u00ed",
    "Previous (Left arrow key)": "P\u0159edchoz\u00ed (\u0161ipkou vlevo)",
    "Processing...": "Zpracov\u00e1v\u00e1m...",
    "Professional Edition": "Komer\u010dn\u00ed vyd\u00e1n\u00ed",
    "Profile": "Profil",
    "Profile Setting": "Nastaven\u00ed profilu",
    "Publish": "Zve\u0159ejnit",
    "Publish a Library": "Zve\u0159ejnit knihovnu",
    "Publish draft": "Zve\u0159ejnit n\u00e1vrh",
    "Published Libraries": "Zve\u0159ejn\u011bn\u00e9 knihovny",
    "Quota": "Kv\u00f3ta",
    "Quota is invalid.": "Neplatn\u00e1 kv\u00f3ta.",
    "Read-Only": "Pouze \u010dten\u00ed",
    "Read-Only folder": "\u010c\u00edst slo\u017eku",
    "Read-Only library": "Knihovna pouze pro \u010dten\u00ed.",
    "Read-Write": "\u010c\u00edst / zapisovat",
    "Read-Write folder": "\u010c\u00edst/Upravovat slo\u017eku",
    "Read-Write library": "\u010cten\u00ed / z\u00e1pis do knihovny",
    "Really want to delete this group?": "Skute\u010dn\u011b chcete smazat tuto skupinu?",
    "Really want to delete your account?": "Opravdu chcete smazat sv\u016fj \u00fa\u010det?",
    "Really want to leave this group?": "Skute\u010dn\u011b chcete opustit tuto skupinu?",
    "Refresh": "Obnovit",
    "Remaining": "Zb\u00fdv\u00e1",
    "Remove": "Odstranit",
    "Remove Member": "Odebrat \u010dlena",
    "Removed all items from trash.": "Odstran\u011bny v\u0161echny polo\u017eky v ko\u0161i.",
    "Removed items older than {n} days from trash.": "Odstran\u011bny v\u0161echny polo\u017eky z ko\u0161e star\u0161\u00ed {n} dn\u00ed.",
    "Rename": "P\u0159ejmenovat",
    "Rename File": "P\u0159ejmenovat soubor",
    "Rename Folder": "P\u0159ejmenovat slo\u017eku",
    "Rename Group": "P\u0159ejmenovat skupinu",
    "Rename group to": "P\u0159ejmenovat skupinu na",
    "Renamed file": "P\u0159ejmenovan\u00fd soubor",
    "Renamed folder": "P\u0159ejmenovan\u00e1 slo\u017eka",
    "Renamed library": "P\u0159ejmenovan\u00e1 knihovna",
    "Renamed or Moved files": "P\u0159ejmenovan\u00e9 nebo p\u0159esunut\u00e9 soubory",
    "Renaming {name} failed": "P\u0159ejmenov\u00e1n\u00ed {name} selhalo",
    "Replace": "Nahradit",
    "Replace file {filename}?": "P\u0159epsat soubor {filename}?",
    "Replacing it will overwrite its content.": "P\u0159eps\u00e1n\u00edm se p\u0159ep\u00ed\u0161e p\u016fvodn\u00ed obsah.",
    "Report Abuse": "Nahl\u00e1sit zneu\u017eit\u00ed",
    "Reporter": "Zpravodaj",
    "Reports": "Reporty",
    "Request a review": "Po\u017e\u00e1dat o kontrolu",
    "Required at least three letters.": "Jsou vy\u017eadov\u00e1na nejm\u00e9n\u011b t\u0159i p\u00edsmena",
    "Reset": "Reset",
    "Reset Password": "Resetovat heslo",
    "Reset library password": "Resetovat heslo knihovny",
    "ResetPwd": "Reset Hesla",
    "Resetting user's password, please wait for a moment.": "Obnoven\u00ed hesla u\u017eivatele, vy\u010dkejte chv\u00edli.",
    "Restore": "Obnovit",
    "Restore Library": "Obnovit knihovnu",
    "Restored file": "Obnoven\u00fd soubor",
    "Restored folder": "Obnovit slo\u017eku",
    "Restored library": "Obnoven\u00e1 knihovna",
    "Result": "V\u00fdsledek",
    "Retry": "Opakovat",
    "Retry All": "Opakovat v\u0161e",
    "Revoke": "Zru\u0161it",
    "Revoke Access": "Odebrat p\u0159\u00edstup",
    "Revoke Admin": "Odvolat Admina",
    "Role": "Role",
    "Save": "Ulo\u017eit",
    "Save as ...": "Ulo\u017eit jako ...",
    "Save to:": "Ulo\u017eit do:",
    "Saving...": "Ukl\u00e1d\u00e1m...",
    "Seafile": "Seafile",
    "Search": "Hledat",
    "Search Groups": "Hledat skupiny",
    "Search Libraries": "Hledat knihovny",
    "Search Organizations": "Hledat v organizac\u00edch",
    "Search Users": "Hledat u\u017eivatele",
    "Search files in this library": "Vyhledat soubory v t\u00e9to knihovn\u011b",
    "Search groups": "Vyhledat skupiny",
    "Search groups by name": "Hledat skupiny podle n\u00e1zvu",
    "Search libraries by owner": "Hledat v knihovn\u00e1ch podle vlastn\u00edka",
    "Search organizations": "Hledat organizace",
    "Search users": "Vyhledat u\u017eivatele",
    "Searching...": "Vyhled\u00e1v\u00e1m...",
    "Select File": "Vybrat soubor",
    "Select Image": "Vybrat obr\u00e1zek",
    "Select Tags": "Vybrat \u0161t\u00edtky",
    "Select a color": "Vybrat barvu",
    "Select a department": "Vybrat odd\u011blen\u00ed",
    "Select a group": "Vyberte skupinu",
    "Select a user": "Vybrat u\u017eivatele",
    "Select groups": "Vyberte skupiny",
    "Select libraries to share": "Vyberte knihovnu ke sd\u00edlen\u00ed",
    "Send": "Odeslat",
    "Send activation Email after user registration.": "Odes\u00edlat aktiva\u010dn\u00ed e-mail po registraci.",
    "Send to:": "Odeslat na:",
    "Sending new password...": "Odes\u00edl\u00e1n\u00ed nov\u00e9ho hesla...",
    "Sending...": "Odes\u00edl\u00e1m...",
    "Server": "Server",
    "Server Version: ": "Verze serveru: ",
    "Set Admin": "Nastavit spr\u00e1vce",
    "Set Contact Email": "Nastavit kontaktn\u00ed email",
    "Set Login ID": "Nastavit p\u0159ihla\u0161ovac\u00ed ID",
    "Set Name": "Nastavit jm\u00e9no",
    "Set Password": "Nastavit heslo",
    "Set Quota": "Nastavit kv\u00f3tu",
    "Set Reference ID": "Nastavit referen\u010dn\u00ed ID",
    "Set max number of members": "Nastavit maxim\u00e1ln\u00ed po\u010det \u010dlen\u016f",
    "Set permission": "Nastavit opr\u00e1vn\u011bn\u00ed",
    "Set to current": "Nastavit jako aktu\u00e1ln\u00ed",
    "Set user contact email": "Nastavit kontaktn\u00ed e-mail u\u017eivatele",
    "Set user name": "Nastavit u\u017eivatelsk\u00e9 jm\u00e9no",
    "Set user quota": "Nastavit kv\u00f3tu u\u017eivatele",
    "Set {placeholder}'s permission": "Nastaven\u00ed {placeholder}'s opr\u00e1vn\u011bn\u00ed",
    "Setting library history is disabled by Admin.": "Nastaven\u00ed historie knihoven je vypnuto administr\u00e1torem.",
    "Settings": "Nastaven\u00ed",
    "Share": "Sd\u00edlet",
    "Share Admin": "Sd\u00edlen\u00ed Admin",
    "Share From": "Sd\u00edleno od",
    "Share Link": "Ve\u0159ejn\u00fd odkaz",
    "Share Link Traffic": "Provoz sd\u00edlec\u00edho odkazu",
    "Share Links": "Ve\u0159ejn\u00e9 odkazy",
    "Share To": "Sd\u00edlet s",
    "Share To:": "Sd\u00edlet s:",
    "Share existing libraries": "Sd\u00edlet existuj\u00edc\u00ed knihovny",
    "Share link download": "Sd\u00edlet odkaz ke sta\u017een\u00ed",
    "Share link is copied to the clipboard.": "Ve\u0159ejn\u00fd odkaz zkop\u00edrov\u00e1n do schr\u00e1nky.",
    "Share link upload": "Sd\u00edlet odkaz k nahr\u00e1n\u00ed",
    "Share to group": "Sd\u00edlet skupin\u011b",
    "Share to other server": "Sd\u00edlet na jin\u00fd server",
    "Share to user": "Sd\u00edlet u\u017eivateli",
    "Share {placeholder}": "Sd\u00edlen\u00ed {placeholder}",
    "Shared By": "Sd\u00edleno u\u017eivatelem",
    "Shared Libraries": "Sd\u00edlen\u00e9 knihovny",
    "Shared Links": "Sd\u00edlen\u00e9 odkazy",
    "Shared by:": "Sd\u00edleno od:",
    "Shared by: ": "Sd\u00edleno u\u017eivatelem: ",
    "Shared from other servers": "Sd\u00edleno z jin\u00fdch server\u016f",
    "Shared with all": "Sd\u00edleno se v\u0161emi",
    "Shared with groups": "Sd\u00edleno se skupinami",
    "Shared with me": "Sd\u00edleno se mnou",
    "Show": "Zobraz",
    "Show Codes": "Zobrazit k\u00f3dy",
    "Side Nav Menu": "Postrann\u00ed naviga\u010dn\u00ed nab\u00eddka",
    "Site name used in email sending": "N\u00e1zev str\u00e1nky pou\u017eit\u00fd v odeslan\u00fdch e-mailech",
    "Site title shown in a browser tab": "Titulek str\u00e1nky je zobrazen v z\u00e1lo\u017ece prohl\u00ed\u017ee\u010de.",
    "Size": "Velikost",
    "Social Login": "P\u0159ihl\u00e1\u0161en\u00ed na soci\u00e1ln\u00ed s\u00edti",
    "Space Used": "Vyu\u017eit\u00e9 m\u00edsto",
    "Space Used / Quota": "Vyu\u017eit\u00e9 m\u00edsto / Kv\u00f3ta",
    "Star": "Hv\u011bzdi\u010dka",
    "Start": "Za\u010d\u00e1tek",
    "Start date": "Po\u010d\u00e1te\u010dn\u00ed datum",
    "Statistic": "Statistika",
    "Status": "Stav",
    "Status: enabled": "Stav: zapnuto",
    "Storage": "Ulo\u017ei\u0161t\u011b",
    "Storage Backend": "Typ ulo\u017ei\u0161t\u011b",
    "Storage Used": "Pou\u017eit\u00e9 m\u00edsto",
    "Sub-departments": "Pododd\u011blen\u00ed",
    "Submit": "Odeslat",
    "Success": "Dokon\u010deno",
    "Successfully added label(s) for library {placeholder}": "\u00dasp\u011b\u0161n\u011b p\u0159id\u00e1ny \u0161t\u00edtky pro knihovnu {placeholder}",
    "Successfully added {email_placeholder}": "\u00dasp\u011b\u0161n\u011b p\u0159id\u00e1n {email_placeholder}",
    "Successfully changed library password.": "Heslo knihovny bylo \u00fasp\u011b\u0161n\u011b zm\u011bn\u011bno.",
    "Successfully cleaned all errors.": "V\u0161echny chyby byly \u00fasp\u011b\u0161n\u011b vymaz\u00e1ny.",
    "Successfully cleared trash.": "Ko\u0161 byl \u00fasp\u011b\u0161n\u011b odstran\u011bn.",
    "Successfully copied %(name)s and %(amount)s other items.": "\u00dasp\u011b\u0161n\u011b zkop\u00edrov\u00e1n %(name)s a %(amount)s dal\u0161\u00edch polo\u017eek.",
    "Successfully copied %(name)s and 1 other item.": "\u00dasp\u011b\u0161n\u011b zkop\u00edrov\u00e1n %(name)s a 1 dal\u0161\u00ed polo\u017eka.",
    "Successfully copied %(name)s.": "\u00dasp\u011b\u0161n\u011b zkop\u00edrov\u00e1n %(name)s.",
    "Successfully copied files to another library.": "Soubory byly \u00fasp\u011b\u0161n\u011b zkop\u00edrov\u00e1ny do jin\u00e9 knihovny.",
    "Successfully deleted %(name)s": "\u00dasp\u011b\u0161n\u011b smaz\u00e1n %(name)s",
    "Successfully deleted %(name)s and %(amount)s other items.": "\u00dasp\u011b\u0161n\u011b smaz\u00e1no %(name)s a %(amount)s dal\u0161\u00edch polo\u017eek.",
    "Successfully deleted %(name)s and 1 other item.": "\u00dasp\u011b\u0161n\u011b smaz\u00e1no %(name)s a 1 dal\u0161\u00ed polo\u017eka.",
    "Successfully deleted %(name)s.": "\u00dasp\u011b\u0161n\u011b smaz\u00e1n %(name)s.",
    "Successfully deleted 1 item": "\u00dasp\u011b\u0161n\u011b smaz\u00e1na 1 polo\u017eka",
    "Successfully deleted 1 item.": "\u00dasp\u011b\u0161n\u011b smaz\u00e1na 1 polo\u017eka",
    "Successfully deleted 1 user.": "1 u\u017eivatel byl \u00fasp\u011b\u0161n\u011b smaz\u00e1n.",
    "Successfully deleted draft %(draft)s.": "\u00dasp\u011b\u0161n\u011b smazan\u00fd n\u00e1vrh %(draft)s.",
    "Successfully deleted {name}": "\u00dasp\u011b\u0161n\u011b smaz\u00e1n {name}",
    "Successfully deleted {name}.": "\u00dasp\u011b\u0161n\u011b smz\u00e1n {name}.",
    "Successfully deleted {user_number_placeholder} users.": "\u00dasp\u011b\u0161n\u011b smaz\u00e1no {user_number_placeholder} u\u017eivatel\u016f.",
    "Successfully edited labels.": "\u0160t\u00edtky byly \u00fasp\u011b\u0161n\u011b upraveny.",
    "Successfully invited %(email) and %(num) other people.": "\u00dasp\u011b\u0161n\u011b pozv\u00e1n %(email) a dal\u0161\u00edch %(num) lid\u00ed.",
    "Successfully invited %(email).": "\u00dasp\u011b\u0161n\u011b pozv\u00e1n %(email).",
    "Successfully modified permission.": "Opr\u00e1vn\u011bn\u00ed \u00fasp\u011b\u0161n\u011b zm\u011bn\u011bna.",
    "Successfully moved %(name)s and %(amount)s other items.": "\u00dasp\u011b\u0161n\u011b p\u0159esunut %(name)s a %(amount)s dal\u0161\u00edch polo\u017eek.",
    "Successfully moved %(name)s and 1 other item.": "\u00dasp\u011b\u0161n\u011b p\u0159esunut %(name)s a 1 dal\u0161\u00ed polo\u017eka.",
    "Successfully moved %(name)s.": "\u00dasp\u011b\u0161n\u011b p\u0159esunut %(name)s.",
    "Successfully moved files to another library.": "Soubory byly \u00fasp\u011b\u0161n\u011b p\u0159esunuty do jin\u00e9 knihovny.",
    "Successfully moved {name}.": "\u00dasp\u011b\u0161n\u011b p\u0159esunut {name}.",
    "Successfully published draft %(draft)s.": "\u00dasp\u011b\u0161n\u011b zve\u0159ejn\u011bn\u00fd n\u00e1vrh %(draft)s.",
    "Successfully removed {placeholder}.": "\u00dasp\u011b\u0161n\u011b odstran\u011bn {placeholder}.",
    "Successfully reset password to %(passwd)s for user %(user)s.": "\u00dasp\u011b\u0161n\u011b vyresetov\u00e1no heslo na %(passwd)s pro u\u017eivatele %(user)s",
    "Successfully restored 1 item.": "1 polo\u017eka byla \u00fasp\u011b\u0161n\u011b obnovena.",
    "Successfully restored the library.": "Knihovna \u00fasp\u011b\u0161n\u011b obnovena.",
    "Successfully restored.": "\u00dasp\u011b\u0161n\u011b obnoveno",
    "Successfully revoke the admin permission of %s": "\u00dasp\u011b\u0161n\u011b zru\u0161ena admin opr\u00e1vn\u011bn\u00ed u\u017eivatele %s",
    "Successfully revoked access of user {placeholder}.": "P\u0159\u00edstup u\u017eivatele {placeholder} byl \u00fasp\u011b\u0161n\u011b odebr\u00e1n.",
    "Successfully revoked the admin permission of {placeholder}.": "\u00dasp\u011b\u0161n\u011b zru\u0161eno administr\u00e1torsk\u00e9 opr\u00e1vn\u011bn\u00ed {placeholder}.",
    "Successfully saved": "\u00dasp\u011b\u0161n\u011b ulo\u017eeno",
    "Successfully sent to {placeholder}": "\u00dasp\u011b\u0161n\u011b nahr\u00e1no do {placeholder}",
    "Successfully set %s as admin.": "U\u017eivatel %s byl \u00fasp\u011b\u0161n\u011b nastaven jako Admin",
    "Successfully set it.": "\u00dasp\u011b\u0161n\u011b nastaveno.",
    "Successfully set library history.": "Nastaven\u00ed historie knihovny bylo \u00fasp\u011b\u0161n\u00e9.",
    "Successfully starred {library_name_placeholder}.": "\u00dasp\u011b\u0161n\u011b ozna\u010deno hv\u011bzdi\u010dkou {library_name_placeholder}.",
    "Successfully transferred the group.": "Skupina byla \u00fasp\u011b\u0161n\u011b p\u0159esunuta.",
    "Successfully transferred the library.": "Knihovna byla \u00fasp\u011b\u0161n\u011b p\u0159esunuta.",
    "Successfully unlinked %(name)s.": "\u00dasp\u011b\u0161n\u011b zru\u0161en odkaz %(name)s.",
    "Successfully unlinked the device.": "Za\u0159\u00edzen\u00ed bylo \u00fasp\u011b\u0161n\u011b odpojeno.",
    "Successfully unshared library {placeholder}": "\u00dasp\u011b\u0161n\u011b zru\u0161eno sd\u00edlen\u00ed {placeholder}",
    "Successfully unshared {name}": "Sd\u00edlen\u00ed {name} \u00fasp\u011b\u0161n\u011b zru\u0161eno",
    "Successfully unstared {placeholder}": "\u00dasp\u011b\u0161n\u011b zru\u0161en p\u0159\u00edznak {placeholder}",
    "Successfully unstarred {library_name_placeholder}.": "Ozna\u010den\u00ed hv\u011bzdi\u010dkou \u00fasp\u011b\u0161n\u011b zru\u0161eno {library_name_placeholder}.",
    "Suggestion": "N\u00e1vrh",
    "Switch to plain text editor": "P\u0159epnout do textov\u00e9ho editoru",
    "Switch to rich text editor": "P\u0159epnout do roz\u0161\u00ed\u0159en\u00e9ho textov\u00e9ho editoru",
    "Sync": "Synchronizace",
    "Sync Download": "Sta\u017een\u00ed synchronizac\u00ed",
    "Sync Traffic": "Provoz synchronizace",
    "Sync Upload": "Nahr\u00e1n\u00ed synchronizac\u00ed",
    "System": "Syst\u00e9m",
    "System Admin": "Spr\u00e1vce syst\u00e9mu",
    "System Info": "Informace o syst\u00e9mu",
    "Tag \"{name}\" already exists.": "\u0160t\u00edtek \"{name}\" ji\u017e existuje.",
    "Tagged Files": "O\u0161t\u00edtkovan\u00e9 soubory",
    "Tags": "\u0160t\u00edtky",
    "Template": "\u0160ablona",
    "Terms": "Podm\u00ednky",
    "Terms and Conditions": "Pravidla a podm\u00ednky",
    "Text": "Text",
    "Text files": "Textov\u00e9 soubory",
    "Text is required.": "Je vy\u017eadov\u00e1n text.",
    "The URL of the server, like https://seafile.example.com or http://192.168.1.2:8000": "URL serveru jako https://seafile.example.com nebo http://192.168.1.2:8000",
    "The file is too large. Allowed maximum size is 1MB.": "Soubor je p\u0159\u00edli\u0161 velk\u00fd. Nejvy\u0161\u0161\u00ed umo\u017en\u011bn\u00e1 velikost je 1MB.",
    "The internal URL for downloading/uploading files. Users will not be able to download/upload files if this is not set correctly. If you config Seafile behind Nginx/Apache, it should be SERVICE_URL/seafhttp, like https://seafile.example.com/seafhttp .": "Intern\u00ed URL pro nahr\u00e1v\u00e1n\u00ed/stahov\u00e1n\u00ed soubor\u016f. U\u017eivatel\u00e9 nebudou schopni nahr\u00e1vat/stahovat, jestli\u017ee tato mo\u017enost nebude nastavena spr\u00e1vn\u011b. Pokud m\u00e1te Seafile zprovozn\u011bn\u00fd za Nginx/Apache, m\u011blo by to b\u00fdt URL_SLU\u017dBY/seafhttp, jako t\u0159eba https://seafile.example.com/seafhttp .",
    "The least number of characters an account password should include.": "Minim\u00e1ln\u00ed po\u010det znak\u016f, kter\u00e9 by heslo m\u011blo obsahovat.",
    "The least number of characters an encrypted library password should include.": "Minim\u00e1ln\u00ed po\u010det znak\u016f, kter\u00e9 by heslo knihovny m\u011blo obsahovat",
    "The level(1-4) of an account password's strength. For example, '3' means password must have at least 3 of the following: num, upper letter, lower letter and other symbols": "\u00darove\u0148 (1-4) s\u00edly hesla. Nap\u0159\u00edklad '3' znamen\u00e1, \u017ee heslo mus\u00ed obsahovat minim\u00e1ln\u011b 3 v\u011bci z n\u00e1sleduj\u00edc\u00edho seznamu: \u010d\u00edslo, velk\u00e9 p\u00edsmeno, mal\u00e9 p\u00edsmeno, speci\u00e1ln\u00ed znaky",
    "The link is copied to the clipboard.": "Odkaz byl zkop\u00edrov\u00e1n do schr\u00e1nky",
    "The list of added, deleted and modified files will be sent to your mailbox.": "Seznam p\u0159idan\u00fdch, odstran\u011bn\u00fdch a upraven\u00fdch soubor\u016f bude odesl\u00e1n do va\u0161\u00ed po\u0161tovn\u00ed schr\u00e1nky.",
    "The maximum number of failed login attempts before showing CAPTCHA.": "Maxim\u00e1ln\u00ed po\u010det pokus\u016f o p\u0159ihl\u00e1\u0161en\u00ed p\u0159ed zobrazen\u00edm CAPTCHA.",
    "The name \"{name}\" is already taken. Please choose a different name.": "Jm\u00e9no \"{name}\" je ji\u017e obsazeno. Pros\u00edm zvolte jin\u00e9 jm\u00e9no.",
    "The owner of this library has run out of space.": "Vlastn\u00edk t\u00e9to knihovny nem\u00e1 voln\u00e9 m\u00edsto.",
    "The password will be kept in the server for only 1 hour.": "Heslo bude ulo\u017eeno na serveru pouze 1 hodinu.",
    "This file has been updated.": "Tento soubor byl aktualizov\u00e1n.",
    "This file is in draft stage.": "Tento soubor je ve f\u00e1zi n\u00e1vrhu.",
    "This folder has no content at this time.": "Tato slo\u017eka aktu\u00e1ln\u011b nic neobsahuje.",
    "This is a special group representing a department.": "Toto je speci\u00e1ln\u00ed skupina reprezentuj\u00edc\u00ed odd\u011blen\u00ed.",
    "This library has been set to read-only by admin and cannot be updated.": "Tato knihovna byla nastavena spr\u00e1vcem pouze pro \u010dten\u00ed a nelze ji aktualizovat.",
    "This library is password protected": "Tato knihovna je chr\u00e1n\u011bna heslem",
    "This operation will not be reverted. Please think twice!": "Tuto operaci nebude mo\u017eno vz\u00edt zp\u011bt. Pros\u00edm ujist\u011bte se, \u017ee to opravdu chcete!",
    "Time": "\u010cas",
    "Tip: -2 means no limit.": "Tip: -2 znamen\u00e1 bez limitu.",
    "Tip: 0 means default limit": "Tip: 0 znamen\u00e1 v\u00fdchoz\u00ed limit",
    "Tip: a snapshot will be generated after modification, which records the library state after the modification.": "Tip: Snapshot bude generov\u00e1n po modifikaci, kter\u00fd zaznamen\u00e1 stav knihovny po modifikaci.",
    "Tip: libraries deleted {placeholder} days ago will be cleaned automatically.": "Tip: Knihovny smazan\u00e9 p\u0159ed {placeholder} dny budou automaticky vymaz\u00e1ny.",
    "Tip: libraries deleted {trashReposExpireDays} days ago will be cleaned automatically.": "Tip: knihovny smazan\u00e9 p\u0159ed {trashReposExpireDays} dny budou automaticky odstran\u011bny.",
    "Tip: you can search by keyword in name.": "Tip: M\u016f\u017eete vyhled\u00e1vat podle kl\u00ed\u010dov\u00e9ho slova ve jm\u00e9n\u011b.",
    "Token": "K\u00f3d",
    "Tools": "N\u00e1stroje",
    "Total Devices": "Celkem za\u0159\u00edzen\u00ed",
    "Total Storage": "Celkov\u00e9 ulo\u017ei\u0161t\u011b",
    "Total Traffic": "Celkov\u00fd provoz",
    "Total Users": "Celkov\u00fd po\u010det u\u017eivatel\u016f",
    "Traffic": "Vyt\u00ed\u017een\u00ed",
    "Transfer": "P\u0159evod",
    "Transfer Group": "P\u0159ev\u00e9st skupinu",
    "Transfer Group {placeholder} to": "P\u0159ev\u00e9st skupinu {placeholder} na",
    "Transfer Library": "P\u0159evod knihovny",
    "Transfer Library {library_name}": "P\u0159ev\u00e9st knihovnu {library_name}",
    "Transfer group to": "P\u0159ev\u00e9st skupinu na",
    "Transfer to department": "P\u0159ev\u00e9st odd\u011blen\u00ed",
    "Transfer to user": "P\u0159ev\u00e9st u\u017eivateli",
    "Transferred group {group_name} from {user_from} to {user_to}": "Skupina {group_name} byla p\u0159evedena od u\u017eivatele {user_from} k u\u017eivateli {user_to}",
    "Transferred library {library_name} from {user_from} to {user_to}": "Knihovna {library_name} byla p\u0159evedena od u\u017eivatele {user_from} k u\u017eivateli {user_to}",
    "Trash": "Ko\u0161",
    "Two-Factor Authentication": "Dvoufaktorov\u00e1 autentizace",
    "Two-factor authentication is not enabled for your account. Enable two-factor authentication for enhanced account security.": "Dvoufaktorov\u00e1 autentizace nen\u00ed zapnuta pro V\u00e1\u0161 \u00fa\u010det. Zapn\u011bte dvoufaktorovou autentizaci pro zv\u00fd\u0161en\u00ed zabezpe\u010den\u00ed va\u0161eho \u00fa\u010dtu.",
    "Type": "Typ",
    "Unhandled": "Neo\u0161et\u0159en\u00e9",
    "Unknown": "Nezn\u00e1m\u00fd",
    "Unlink": "Odp\u00e1rovat",
    "Unlink device": "Odpojit za\u0159\u00edzen\u00ed",
    "Unlock": "Odemknout",
    "Unpublish": "Zru\u0161it zve\u0159ejn\u011bn\u00ed",
    "Unpublish Library": "Zru\u0161it zve\u0159ejn\u011bn\u00ed knihovny",
    "Unshare": "Zru\u0161it sd\u00edlen\u00ed",
    "Unshare Library": "Zru\u0161it sd\u00edlen\u00ed knihovny",
    "Unstar": "Odebrat z obl\u00edben\u00fdch",
    "Update": "Aktualizovat",
    "Update Terms and Conditions": "Aktualizovat pravidla a podm\u00ednky",
    "Update succeeded.": "Aktualizace prob\u011bhla \u00fasp\u011b\u0161n\u011b.",
    "Updated draft": "Aktualizovan\u00fd koncept",
    "Updated file": "Aktualizovan\u00fd soubor",
    "Upgrade to Pro Edition": "P\u0159ej\u00edt na komer\u010dn\u00ed vyd\u00e1n\u00ed",
    "Upload": "Nahr\u00e1t",
    "Upload Files": "Nahr\u00e1t soubory",
    "Upload Folder": "Nahr\u00e1t adres\u00e1\u0159",
    "Upload Link": "Upload odkaz",
    "Upload Link:": "Odkaz pro nahr\u00e1v\u00e1n\u00ed:",
    "Upload Links": "Upload odkazy",
    "Upload file": "Nahr\u00e1t soubor",
    "Upload files to {folder_name_placeholder}": "Nahr\u00e1t soubory do {folder_name_placeholder}",
    "Upload license": "Nahr\u00e1t licenci",
    "Upload link is copied to the clipboard.": "Odkaz pro nahr\u00e1v\u00e1n\u00ed zkop\u00edrov\u00e1n do schr\u00e1nky.",
    "Uploaded": "Nahr\u00e1no",
    "Uploaded bytes exceed file size": "Nahr\u00e1van\u00fd soubor p\u0159ekro\u010dil dovolenou velikost",
    "Use custom CSS": "Pou\u017eit vlastn\u00ed CSS",
    "Use draft": "Pou\u017e\u00edt koncept",
    "Used:": "Vyu\u017eito:",
    "User": "U\u017eivatel",
    "User Email": "Email u\u017eivatele",
    "User Permission": "U\u017eivatelsk\u00e9 opr\u00e1vn\u011bn\u00ed",
    "User Storage": "U\u017eivatelsk\u00e9 ulo\u017eit\u011b",
    "User can only view files online via browser. Files can't be downloaded.": "U\u017eivatel m\u016f\u017ee pouze prohl\u00ed\u017eet soubory on-line pomoc\u00ed prohl\u00ed\u017ee\u010de. Soubory nemohou b\u00fdt sta\u017eeny.",
    "User can read, download and sync files.": "U\u017eivatel m\u016f\u017ee \u010d\u00edst, stahovat a synchronizovat soubory.",
    "User can read, write, upload, download and sync files.": "U\u017eivatel m\u016f\u017ee \u010d\u00edst, zapisovat, nahr\u00e1vat, stahovat a synchronizovat soubory.",
    "User can view and edit file online via browser. Files can't be downloaded.": "U\u017eivatel m\u016f\u017ee prohl\u00ed\u017eet a upravovat soubor online prost\u0159ednictv\u00edm prohl\u00ed\u017ee\u010de. Soubory nelze st\u00e1hnout.",
    "User not found": "U\u017eivatel nebyl nalezen.",
    "User {user_link} has added you to {group_link}": "U\u017eivatel {user_link} V\u00e1s p\u0159idal do skupiny {group_link}",
    "Username:": "U\u017eivatelsk\u00e9 jm\u00e9no:",
    "Users": "U\u017eivatel\u00e9",
    "Verify": "Ov\u011b\u0159it",
    "Version": "Verze",
    "Version Number": "\u010c\u00edslo verze",
    "Version Number is required.": "\u010c\u00edslo verze je povinn\u00e9.",
    "Version Number must be a number.": "\u010c\u00edslo verze mus\u00ed b\u00fdt \u010d\u00edslo.",
    "Video": "Video",
    "View": "Zobrazit",
    "View Draft": "Zobrazit koncept",
    "View Link": "Zobrazit odkaz",
    "View Snapshot": "Prohl\u00e9dnout Snapshot",
    "View profile and more": "Zobrazit profil a v\u00edce",
    "Virus": "Virus",
    "Virus File": "Naka\u017een\u00fd soubor",
    "Virus Scan": "Virov\u00e1 kontrola",
    "Visited": "Nav\u0161t\u00edveno",
    "Visits": "N\u00e1v\u0161t\u011bvy",
    "Web API Auth Token": "Web API Auth Token",
    "Web Download": "Sta\u017een\u00ed z webu",
    "Web Traffic": "Provoz webu",
    "Web Upload": "Nahr\u00e1n\u00ed p\u0159es web",
    "WebDav Password": "WebDav heslo",
    "Welcome to {site_name_placeholder}": "V\u00edtejte v {site_name_placeholder}",
    "Wrong password": "Chybn\u00e9 heslo",
    "Yes": "Ano",
    "You are not in any groups. Groups allow multiple people to collaborate on libraries. Groups you join will be listed here.": "Nejste v \u017e\u00e1dn\u00e9 skupin\u011b. Skupiny umo\u017e\u0148uj\u00ed v\u00edce lidem spolupracovat na knihovn\u00e1ch. Zde budou uvedeny skupiny, ke kter\u00fdm se p\u0159ipoj\u00edte.",
    "You are not in any groups. Groups allow multiple people to collaborate on libraries. You can create a group by clicking the \"New Group\" button in the menu bar.": "Nejste v \u017e\u00e1dn\u00e9 skupin\u011b. Skupiny umo\u017e\u0148uj\u00ed v\u00edce lidem spolupracovat na knihovn\u00e1ch. Skupinu m\u016f\u017eete vytvo\u0159it kliknut\u00edm na tla\u010d\u00edtko \u201eNov\u00e1 skupina\u201c na panelu nab\u00eddek.",
    "You can also add a user as a guest, who will not be allowed to create libraries and groups.": "M\u016f\u017eete tak\u00e9 p\u0159idat u\u017eivatele jako hosta, kter\u00fd nebude opr\u00e1vn\u011bn vytv\u00e1\u0159et knihovny a skupiny.",
    "You can create files quickly": "Soubory m\u016f\u017eete vytvo\u0159it ihned",
    "You can create libraries by clicking the \"New Library\" button above.": "Knihovny m\u016f\u017eete vytvo\u0159it kliknut\u00edm na tla\u010d\u00edtko \"Nov\u00e1 knihovna\" n\u00ed\u017ee.",
    "You can use this field at login.": "Tuto kolonku je mo\u017en\u00e9 pou\u017e\u00edt p\u0159i p\u0159ihla\u0161ov\u00e1n\u00ed.",
    "You don't have any favorite items yet": "Zat\u00edm nem\u00e1te \u017e\u00e1dn\u00e9 obl\u00edben\u00e9 polo\u017eky",
    "You don't have any share links": "Nem\u00e1te \u017e\u00e1dn\u00e9 ve\u0159ejn\u00e9 odkazy",
    "You don't have any upload links": "Nem\u00e1te \u017e\u00e1dn\u00e9 odkazy k odesl\u00e1n\u00ed",
    "You have an unsaved draft. Do you like to use it?": "M\u00e1te neulo\u017een\u00fd koncept. Chcete ho pou\u017e\u00edt?",
    "You have not accessed your files with any client (desktop or mobile) yet. Configure clients on your devices to access your data more comfortably.": "Dosud jste ke sv\u00fdm soubor\u016fm nep\u0159istupovali pomoc\u00ed \u017e\u00e1dn\u00e9ho klienta (stoln\u00edho nebo mobiln\u00edho). Nakonfigurujte klienty na sv\u00fdch za\u0159\u00edzen\u00edch, abyste m\u011bli pohodln\u011bj\u0161\u00ed p\u0159\u00edstup k dat\u016fm.",
    "You have not added any libraries, folders or files to your favorites yet. A favorite gives you quick access to your most frequently used objects. You can add a library, folder or file to your favorites by clicking the star to the left of its name.": "Dosud jste nep\u0159idali \u017e\u00e1dn\u00e9 knihovny, slo\u017eky ani soubory do sv\u00fdch obl\u00edben\u00fdch. Obl\u00edben\u00e9 polo\u017eky v\u00e1m umo\u017en\u00ed rychl\u00fd p\u0159\u00edstup k nej\u010dast\u011bji pou\u017e\u00edvan\u00fdm objekt\u016fm. Knihovnu, slo\u017eku nebo soubor m\u016f\u017eete p\u0159idat do obl\u00edben\u00fdch polo\u017eek kliknut\u00edm na hv\u011bzdi\u010dku nalevo od jej\u00edho n\u00e1zvu.",
    "You have not created any libraries yet. A library is a container to organize your files and folders. A library can also be shared with others and synced to your connected devices. You can create a library by clicking the \"New Library\" button in the menu bar.": "Je\u0161t\u011b jste nevytvo\u0159ili \u017e\u00e1dn\u00e9 knihovny. Knihovna je kontejner pro uspo\u0159\u00e1d\u00e1n\u00ed soubor\u016f a slo\u017eek. Knihovnu lze tak\u00e9 sd\u00edlet s ostatn\u00edmi a synchronizovat s p\u0159ipojen\u00fdmi za\u0159\u00edzen\u00edmi. Knihovnu m\u016f\u017eete vytvo\u0159it kliknut\u00edm na tla\u010d\u00edtko \u201eNov\u00e1 knihovna\u201c na panelu nab\u00eddek.",
    "You have not created any share links yet. A share link can be used to share files and folders with anyone. You can create a share link for a file or folder by clicking the share icon to the right of its name.": "Dosud jste nevytvo\u0159ili \u017e\u00e1dn\u00e9 odkazy na sd\u00edlen\u00ed. Odkaz lze pou\u017e\u00edt ke sd\u00edlen\u00ed soubor\u016f a slo\u017eek s k\u00fdmkoli. Odkaz na sd\u00edlen\u00ed pro soubor nebo slo\u017eku m\u016f\u017eete vytvo\u0159it kliknut\u00edm na ikonu sd\u00edlen\u00ed napravo od jej\u00edho n\u00e1zvu.",
    "You have not created any upload links yet. An upload link allows anyone to upload files to a folder or library. You can create an upload link for a folder or library by clicking the share icon to the right of its name.": "Dosud jste nevytvo\u0159ili \u017e\u00e1dn\u00e9 odkazy pro nahr\u00e1v\u00e1n\u00ed. Odkaz na nahr\u00e1n\u00ed umo\u017e\u0148uje komukoli nahr\u00e1t soubory do slo\u017eky nebo knihovny. Odkaz na nahr\u00e1n\u00ed pro slo\u017eku nebo knihovnu m\u016f\u017eete vytvo\u0159it kliknut\u00edm na ikonu sd\u00edlen\u00ed napravo od jej\u00edho n\u00e1zvu.",
    "You have not deleted any libraries in the last {placeholder} days. A deleted library will be cleaned automatically after this period.": "Za posledn\u00ed {placeholder} dny jste neodstranili \u017e\u00e1dn\u00e9 knihovny. Po t\u00e9to dob\u011b bude odstran\u011bn\u00e1 knihovna automaticky vymaz\u00e1na.",
    "You have not invited any guests yet. A guest can access shared libraries through the web interface allowing more efficient ways to collaborate than through links. You can invite a guest by clicking the \"Invite Guest\" button in the menu bar.": "Dosud jste nepozvali \u017e\u00e1dn\u00e9 hosty. Host m\u00e1 p\u0159\u00edstup ke sd\u00edlen\u00fdm knihovn\u00e1m prost\u0159ednictv\u00edm webov\u00e9ho rozhran\u00ed, co\u017e umo\u017e\u0148uje efektivn\u011bj\u0161\u00ed zp\u016fsoby spolupr\u00e1ce ne\u017e prost\u0159ednictv\u00edm odkaz\u016f. M\u016f\u017eete pozvat hosta kliknut\u00edm na tla\u010d\u00edtko \u201ePozvat hosta\u201c na li\u0161t\u011b nab\u00eddek.",
    "You have not published any libraries yet. A published library can be accessed by anyone, not only users, via its URL. You can publish a library by clicking the \"Publish a Library\" button in the menu bar.": "Dosud jste nezve\u0159ejnili \u017e\u00e1dn\u00e9 knihovny. Ke zve\u0159ejn\u011bn\u00e9 knihovn\u011b m\u016f\u017ee prost\u0159ednictv\u00edm sv\u00e9 adresy URL p\u0159istupovat krom\u011b u\u017eivatel\u016f kdokoli. Knihovnu m\u016f\u017eete zve\u0159ejnit kliknut\u00edm na tla\u010d\u00edtko \u201eZve\u0159ejnit knihovnu\u201c na panelu nab\u00eddek.",
    "You have not shared any folders": "Nem\u00e1te \u017e\u00e1dn\u00e9 sd\u00edlen\u00e9 slo\u017eky",
    "You have not shared any folders with other users yet. You can share a folder with other users by clicking the share icon to the right of a folder's name.": "Dosud jste nesd\u00edleli \u017e\u00e1dn\u00e9 slo\u017eky s ostatn\u00edmi u\u017eivateli. Slo\u017eku m\u016f\u017eete sd\u00edlet s ostatn\u00edmi u\u017eivateli kliknut\u00edm na ikonu sd\u00edlen\u00ed napravo od n\u00e1zvu slo\u017eky.",
    "You have not shared any libraries with other users yet. You can share a library with other users by clicking the share icon to the right of a library's name in \"My Libraries\".": "Dosud jste nesd\u00edleli \u017e\u00e1dn\u00e9 knihovny s ostatn\u00edmi u\u017eivateli. Knihovnu m\u016f\u017eete sd\u00edlet s ostatn\u00edmi u\u017eivateli kliknut\u00edm na ikonu sd\u00edlen\u00ed napravo od n\u00e1zvu knihovny v \u010d\u00e1sti \u201eMoje knihovny\u201c.",
    "You have only one backup code remaining.": "Zb\u00fdv\u00e1 v\u00e1m pouze jeden z\u00e1lo\u017en\u00ed k\u00f3d.",
    "You have {num} backup codes remaining.": "Zb\u00fdv\u00e1 v\u00e1m {num} z\u00e1lo\u017en\u00edch k\u00f3d\u016f.",
    "Your notifications will be sent to this email.": "Va\u0161e upozorn\u011bn\u00ed bude odesl\u00e1no na tento e-mail.",
    "ZIP": "ZIP",
    "ZIP Selected Items": "Zkomprimovat vybran\u00e9 polo\u017eky do form\u00e1tu ZIP",
    "activate after registration": "aktivovat po registraci",
    "all": "v\u0161e",
    "all members": "v\u0161ichni \u010dlenov\u00e9",
    "allow new registrations": "povolit nov\u00e9 registrace",
    "canceled": "zru\u0161eno",
    "days": "dn\u00ed",
    "deleted": "Smaz\u00e1no",
    "details": "detaily",
    "email is required": "Email je povinn\u00fd",
    "icon": "ikona",
    "keep sign in": "z\u016fstat p\u0159ihl\u00e1\u0161en",
    "library password minimum length": "minim\u00e1ln\u00ed d\u00e9lka hesla knihovny",
    "licensed to {placeholder_license_to}, expires on {placeholder_license_expiration}": "Licencov\u00e1no na {placeholder_license_to}, vypr\u0161\u00ed dne {placeholder_license_expiration}",
    "licensed to {placeholder_license_to}, upgrade service expired in {placeholder_license_expiration}": "Licencov\u00e1no na {placeholder_license_to}, platnost upgradu slu\u017eby vypr\u0161ela v {placeholder_license_expiration}",
    "locked": "uzam\u010deno",
    "locked by {name}": "zam\u010deno u\u017eivatelem {name}",
    "locked by {placeholder}": "uzam\u010deno {placeholder}",
    "name": "jm\u00e9no",
    "password minimum length": "minim\u00e1ln\u00ed d\u00e9lka hesla",
    "password strength level": "\u00farove\u0148 s\u00edly hesla",
    "progress": "postup",
    "result": "v\u00fdsledek",
    "results": "v\u00fdsledky",
    "send activation email": "odes\u00edlat aktiva\u010dn\u00ed e-mail",
    "shared by:": "sd\u00edleno u\u017eivatelem:",
    "show more": "zobrazit v\u00edce",
    "size": "velikost",
    "starred": "ozna\u010deno",
    "state": "stav",
    "successfully added user %s.": "\u00fasp\u011b\u0161n\u011b p\u0159id\u00e1n u\u017eivatel %s.",
    "text file extensions": "p\u0159\u00edpony textov\u00fdch soubor\u016f",
    "to": "do",
    "unstarred": "odzna\u010deno",
    "uploaded": "nahr\u00e1no",
    "you can also press \u2190 ": "m\u016f\u017eete tak\u00e9 stisknout \u2190 ",
    "you can also press \u2192": "je tak\u00e9 mo\u017en\u00e9 stisknout \u2192",
    "{file} and {n} other files": "{file} a {n} dal\u0161\u00edch soubor\u016f",
    "{from_user} has sent you a request for {draft_link}.": "{from_user} V\u00e1m odeslal \u017e\u00e1dost pro {draft_link}.",
    "{minDays_placeholder} - {maxDays_placeholder} days": "{minDays_placeholder} - {maxDays_placeholder} dn\u00ed",
    "{number_placeholder} / Page": "{number_placeholder} / Strana",
    "{placeholder} API Token": "{placeholder} API Token",
    "{placeholder} Folder Permission": "Opr\u00e1vn\u011bn\u00ed slo\u017eky {placeholder} ",
    "{placeholder} Modification History": "{placeholder} Historie zm\u011bn",
    "{placeholder} Snapshot": "Zachycen\u00fd stav {placeholder}",
    "{placeholder} Trash": "Ko\u0161 na {placeholder}",
    "{share_from} has shared a folder named {repo_link} to group {group_link}.": "{share_from} s Va\u0161\u00ed skupinou {group_link} sd\u00edl\u00ed slo\u017eku {repo_link}.",
    "{share_from} has shared a folder named {repo_link} to you.": "{share_from} s V\u00e1mi sd\u00edl\u00ed slo\u017eku {repo_link}.",
    "{share_from} has shared a library named {repo_link} to group {group_link}.": "{share_from} s Va\u0161\u00ed skupinou {group_link} sd\u00edl\u00ed knihovnu {repo_link}.",
    "{share_from} has shared a library named {repo_link} to you.": "{share_from} s V\u00e1mi sd\u00edl\u00ed knihovnu {repo_link}.",
    "{site_name_placeholder} organizes files into libraries. Each library can be synced and shared separately. However, since you are a guest user now, you can not create libraries.": "{site_name_placeholder} organizuje soubory do knihoven. Ka\u017edou knihovnu lze synchronizovat a sd\u00edlet samostatn\u011b. Jeliko\u017e jste v\u0161ak nyn\u00ed hostem, nem\u016f\u017eete vytv\u00e1\u0159et knihovny.",
    "{site_name_placeholder} organizes files into libraries. Each library can be synced and shared separately. We have created a personal library for you. You can create more libraries later.": "{site_name_placeholder} organizuje soubory do knihoven. Ka\u017edou knihovnu lze synchronizovat a sd\u00edlet samostatn\u011b. Vytvo\u0159ili jsme pro v\u00e1s osobn\u00ed knihovnu. Dal\u0161\u00ed knihovny m\u016f\u017eete vytvo\u0159it pozd\u011bji.",
    "{userCount} user(s) and {repoCount} libraries of this organization will also be deleted.": " {userCount} u\u017eivatel(\u016f) a {repoCount} knihovnen t\u00e9to organizace bude smaz\u00e1no.",
    "{user} has transfered a library named {repo_link} to you.": "{user} V\u00e1m p\u0159evedl knihovnu {repo_link}."
  };
  for (const key in newcatalog) {
    django.catalog[key] = newcatalog[key];
  }
  

  if (!django.jsi18n_initialized) {
    django.gettext = function(msgid) {
      const value = django.catalog[msgid];
      if (typeof value === 'undefined') {
        return msgid;
      } else {
        return (typeof value === 'string') ? value : value[0];
      }
    };

    django.ngettext = function(singular, plural, count) {
      const value = django.catalog[singular];
      if (typeof value === 'undefined') {
        return (count == 1) ? singular : plural;
      } else {
        return value.constructor === Array ? value[django.pluralidx(count)] : value;
      }
    };

    django.gettext_noop = function(msgid) { return msgid; };

    django.pgettext = function(context, msgid) {
      let value = django.gettext(context + '\x04' + msgid);
      if (value.includes('\x04')) {
        value = msgid;
      }
      return value;
    };

    django.npgettext = function(context, singular, plural, count) {
      let value = django.ngettext(context + '\x04' + singular, context + '\x04' + plural, count);
      if (value.includes('\x04')) {
        value = django.ngettext(singular, plural, count);
      }
      return value;
    };

    django.interpolate = function(fmt, obj, named) {
      if (named) {
        return fmt.replace(/%\(\w+\)s/g, function(match){return String(obj[match.slice(2,-2)])});
      } else {
        return fmt.replace(/%s/g, function(match){return String(obj.shift())});
      }
    };


    /* formatting library */

    django.formats = {
    "DATETIME_FORMAT": "j. E Y G:i",
    "DATETIME_INPUT_FORMATS": [
      "%d.%m.%Y %H:%M:%S",
      "%d.%m.%Y %H:%M:%S.%f",
      "%d.%m.%Y %H.%M",
      "%d.%m.%Y %H:%M",
      "%d. %m. %Y %H:%M:%S",
      "%d. %m. %Y %H:%M:%S.%f",
      "%d. %m. %Y %H.%M",
      "%d. %m. %Y %H:%M",
      "%Y-%m-%d %H.%M",
      "%Y-%m-%d %H:%M:%S",
      "%Y-%m-%d %H:%M:%S.%f",
      "%Y-%m-%d %H:%M",
      "%Y-%m-%d"
    ],
    "DATE_FORMAT": "j. E Y",
    "DATE_INPUT_FORMATS": [
      "%d.%m.%Y",
      "%d.%m.%y",
      "%d. %m. %Y",
      "%d. %m. %y",
      "%Y-%m-%d"
    ],
    "DECIMAL_SEPARATOR": ",",
    "FIRST_DAY_OF_WEEK": 1,
    "MONTH_DAY_FORMAT": "j. F",
    "NUMBER_GROUPING": 3,
    "SHORT_DATETIME_FORMAT": "d.m.Y G:i",
    "SHORT_DATE_FORMAT": "d.m.Y",
    "THOUSAND_SEPARATOR": "\u00a0",
    "TIME_FORMAT": "G:i",
    "TIME_INPUT_FORMATS": [
      "%H:%M:%S",
      "%H.%M",
      "%H:%M",
      "%H:%M:%S.%f"
    ],
    "YEAR_MONTH_FORMAT": "F Y"
  };

    django.get_format = function(format_type) {
      const value = django.formats[format_type];
      if (typeof value === 'undefined') {
        return format_type;
      } else {
        return value;
      }
    };

    /* add to global namespace */
    globals.pluralidx = django.pluralidx;
    globals.gettext = django.gettext;
    globals.ngettext = django.ngettext;
    globals.gettext_noop = django.gettext_noop;
    globals.pgettext = django.pgettext;
    globals.npgettext = django.npgettext;
    globals.interpolate = django.interpolate;
    globals.get_format = django.get_format;

    django.jsi18n_initialized = true;
  }
};

